@@ -33,7 +33,13 @@
 #include "wine/test.h"
 
 HWND hMainWnd;
+BOOL g_fBlockHotItemChange;
+BOOL g_fReceivedHotItemChange;
+BOOL g_fExpectedHotItemOld;
+BOOL g_fExpectedHotItemNew;
  
+#define compare(val, exp, format) ok((val) == (exp), #val " value " format " expected " format "\n", (val), (exp));
+
 static void MakeButton(TBBUTTON *p, int idCommand, int fsStyle, int nString) {
   p->iBitmap = -2;
   p->idCommand = idCommand;
@@ -42,8 +48,34 @@ static void MakeButton(TBBUTTON *p, int idCommand, int fsStyle, int nString) {
   p->iString = nString;
 }
 
+static LRESULT MyWnd_Notify(LPARAM lParam)
+{
+    NMHDR *hdr = (NMHDR *)lParam;
+    NMTBHOTITEM *nmhi;
+    switch (hdr->code)
+    {
+        case TBN_HOTITEMCHANGE:
+            nmhi = (NMTBHOTITEM *)lParam;
+            g_fReceivedHotItemChange = TRUE;
+            if (g_fExpectedHotItemOld != g_fExpectedHotItemNew)
+            {
+                compare(nmhi->idOld, g_fExpectedHotItemOld, "%d");
+                compare(nmhi->idNew, g_fExpectedHotItemNew, "%d");
+            }
+            if (g_fBlockHotItemChange)
+                return 1;
+            break;
+    }
+    return 0;
+}
+
 static LRESULT CALLBACK MyWndProc(HWND hWnd, UINT msg, WPARAM wParam, LPARAM lParam)
 {
+    switch (msg)
+    {
+        case WM_NOTIFY:
+            return MyWnd_Notify(lParam);
+    }
     return DefWindowProcA(hWnd, msg, wParam, lParam);
 }
 
@@ -110,6 +142,32 @@ static void rebuild_toolbar(HWND *hToolbar)
     ok(SendMessage(*hToolbar, TB_AUTOSIZE, 0, 0) == 0, "TB_AUTOSIZE failed\n");
 }
 
+void rebuild_toolbar_with_buttons(HWND *hToolbar)
+{
+    TBBUTTON buttons[5];
+    rebuild_toolbar(hToolbar);
+    
+    ZeroMemory(&buttons, sizeof(buttons));
+    buttons[0].idCommand = 1;
+    buttons[0].fsStyle = BTNS_BUTTON;
+    buttons[0].fsState = TBSTATE_ENABLED;
+    buttons[1].idCommand = 3;
+    buttons[1].fsStyle = BTNS_BUTTON;
+    buttons[1].fsState = TBSTATE_ENABLED;
+    buttons[2].idCommand = 5;
+    buttons[2].fsStyle = BTNS_SEP;
+    buttons[2].fsState = TBSTATE_ENABLED;
+    buttons[3].idCommand = 7;
+    buttons[3].fsStyle = BTNS_BUTTON;
+    buttons[3].fsState = TBSTATE_ENABLED;
+    buttons[4].idCommand = 9;
+    buttons[4].fsStyle = BTNS_BUTTON;
+    buttons[4].fsState = 0;  /* disabled */
+    ok(SendMessage(*hToolbar, TB_ADDBUTTONS, 5, (LPARAM)buttons) == 1, "TB_ADDBUTTONS failed\n");
+    ok(SendMessage(*hToolbar, TB_AUTOSIZE, 0, 0) == 0, "TB_AUTOSIZE failed\n");
+}
+
+
 #define CHECK_IMAGELIST(count, dx, dy) { \
     int cx, cy; \
     HIMAGELIST himl = (HIMAGELIST)SendMessageA(hToolbar, TB_GETIMAGELIST, 0, 0); \
@@ -375,6 +433,109 @@ void test_add_string()
     CHECK_STRING_TABLE(14, ret7);
 }
 
+static void expect_hot_notify(int idold, int idnew)
+{
+    g_fExpectedHotItemOld = idold;
+    g_fExpectedHotItemNew = idnew;
+    g_fReceivedHotItemChange = FALSE;
+}
+
+#define check_hot_notify() \
+    ok(g_fReceivedHotItemChange, "TBN_HOTITEMCHANGE not received\n"); \
+    g_fExpectedHotItemOld = g_fExpectedHotItemNew = 0;
+
+void test_hotitem()
+{
+    HWND hToolbar = NULL;
+    TBBUTTONINFO tbinfo;
+    LRESULT ret;
+
+    g_fBlockHotItemChange = FALSE;
+
+    rebuild_toolbar_with_buttons(&hToolbar);
+    /* set TBSTYLE_FLAT. comctl5 allows hot items only for such toolbars.
+     * comctl6 doesn't have this requirement even when theme == NULL */
+    SetWindowLong(hToolbar, GWL_STYLE, TBSTYLE_FLAT | GetWindowLong(hToolbar, GWL_STYLE));
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == -1, "Hot item: %ld, expected -1\n", ret);
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 1, 0);
+    ok(ret == -1, "TB_SETHOTITEM returned %ld, expected -1\n", ret);
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == 1, "Hot item: %ld, expected 1\n", ret);
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 2, 0);
+    ok(ret == 1, "TB_SETHOTITEM returned %ld, expected 1\n", ret);
+
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 0xbeef, 0);
+    ok(ret == 2, "TB_SETHOTITEM returned %ld, expected 2\n", ret);
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == 2, "Hot item: %lx, expected 2\n", ret);
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, -0xbeef, 0);
+    ok(ret == 2, "TB_SETHOTITEM returned %ld, expected 2\n", ret);
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == -1, "Hot item: %lx, expected -1\n", ret);
+
+    expect_hot_notify(0, 7);
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 3, 0);
+    ok(ret == -1, "TB_SETHOTITEM returned %ld, expected -1\n", ret);
+    check_hot_notify();
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == 3, "Hot item: %lx, expected 3\n", ret);
+    g_fBlockHotItemChange = TRUE;
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 2, 0);
+    ok(ret == 3, "TB_SETHOTITEM returned %ld, expected 2\n", ret);
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == 3, "Hot item: %lx, expected 3\n", ret);
+    g_fBlockHotItemChange = FALSE;
+
+    g_fReceivedHotItemChange = FALSE;
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 0xbeaf, 0);
+    ok(ret == 3, "TB_SETHOTITEM returned %ld, expected 3\n", ret);
+    ok(g_fReceivedHotItemChange == FALSE, "TBN_HOTITEMCHANGE received for invalid parameter\n");
+
+    g_fReceivedHotItemChange = FALSE;
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 3, 0);
+    ok(ret == 3, "TB_SETHOTITEM returned %ld, expected 3\n", ret);
+    ok(g_fReceivedHotItemChange == FALSE, "TBN_HOTITEMCHANGE received after a duplication\n");
+
+    expect_hot_notify(7, 0);
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, -0xbeaf, 0);
+    ok(ret == 3, "TB_SETHOTITEM returned %ld, expected 3\n", ret);
+    check_hot_notify();
+    SendMessage(hToolbar, TB_SETHOTITEM, 3, 0);
+
+    /* setting disabled buttons will generate a notify with the button id but no button will be hot */
+    expect_hot_notify(7, 9);
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 4, 0);
+    ok(ret == 3, "TB_SETHOTITEM returned %ld, expected 3\n", ret);
+    check_hot_notify();
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == -1, "Hot item: %lx, expected -1\n", ret);
+    /* enabling the button won't change that */
+    SendMessage(hToolbar, TB_ENABLEBUTTON, 9, TRUE);
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == -1, "TB_SETHOTITEM returned %ld, expected -1\n", ret);
+
+    /* disabling a hot button works */
+    ret = SendMessage(hToolbar, TB_SETHOTITEM, 3, 0);
+    ok(ret == -1, "TB_SETHOTITEM returned %ld, expected -1\n", ret);
+    g_fReceivedHotItemChange = FALSE;
+    SendMessage(hToolbar, TB_ENABLEBUTTON, 7, FALSE);
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == 3, "TB_SETHOTITEM returned %ld, expected 3\n", ret);
+    ok(g_fReceivedHotItemChange == FALSE, "Unexpected TBN_HOTITEMCHANGE\n");
+
+    SendMessage(hToolbar, TB_SETHOTITEM, 1, 0);
+    tbinfo.cbSize = sizeof(TBBUTTONINFO);
+    tbinfo.dwMask = TBIF_STATE;
+    tbinfo.fsState = 0;  /* disabled */
+    g_fReceivedHotItemChange = FALSE;
+    ok(SendMessage(hToolbar, TB_SETBUTTONINFO, 1, (LPARAM)&tbinfo) == TRUE, "TB_SETBUTTONINFO failed\n");
+    ret = SendMessage(hToolbar, TB_GETHOTITEM, 0, 0);
+    ok(ret == 1, "TB_SETHOTITEM returned %ld, expected 1\n", ret);
+    ok(g_fReceivedHotItemChange == FALSE, "Unexpected TBN_HOTITEMCHANGE\n");
+
+}
+
 START_TEST(toolbar)
 {
     WNDCLASSA wc;
@@ -403,6 +564,7 @@ START_TEST(toolbar)
     basic_test();
     test_add_bitmap();
     test_add_string();
+    test_hotitem();
 
     PostQuitMessage(0);
     while(GetMessageA(&msg,0,0,0)) {
