@@ -89,9 +89,8 @@ static const IDirectInputDevice8AVtbl JoystickAvt;
 static const IDirectInputDevice8WVtbl JoystickWvt;
 struct JoystickImpl
 {
-        const void                     *lpVtbl;
-        LONG                            ref;
-        GUID                            guid;
+        struct IDirectInputDevice2AImpl base;
+
 	char				dev[32];
 
 	/* The 'parent' DInput */
@@ -104,7 +103,6 @@ struct JoystickImpl
 	DataFormat			*transform;	/* wine to user format converter */
 	int				*offsets;	/* object offsets */
 	ObjProps			*props;
-        HANDLE				hEvent;
         LPDIDEVICEOBJECTDATA 		data_queue;
         int				queue_head, queue_tail, queue_len;
 	BOOL				acquired;
@@ -495,12 +493,12 @@ static HRESULT alloc_device(REFGUID rguid, const void *jvt, IDirectInputImpl *di
     }
 #endif
 
-    newDevice->lpVtbl = jvt;
-    newDevice->ref = 1;
+    newDevice->base.lpVtbl = jvt;
+    newDevice->base.ref = 1;
     newDevice->dinput = dinput;
     newDevice->acquired = FALSE;
     newDevice->overflow = FALSE;
-    CopyMemory(&(newDevice->guid),rguid,sizeof(*rguid));
+    CopyMemory(&newDevice->base.guid, rguid, sizeof(*rguid));
 
     /* setup_dinput_options may change these */
     newDevice->deadzone = 5000;
@@ -672,7 +670,7 @@ static ULONG WINAPI JoystickAImpl_Release(LPDIRECTINPUTDEVICE8A iface)
     JoystickImpl *This = (JoystickImpl *)iface;
     ULONG ref;
 
-    ref = InterlockedDecrement((&This->ref));
+    ref = InterlockedDecrement(&This->base.ref);
     if (ref)
         return ref;
 
@@ -1214,19 +1212,6 @@ static HRESULT WINAPI JoystickAImpl_SetProperty(
     return DI_OK;
 }
 
-/******************************************************************************
-  *     SetEventNotification : specifies event to be sent on state change
-  */
-static HRESULT WINAPI JoystickAImpl_SetEventNotification(
-	LPDIRECTINPUTDEVICE8A iface, HANDLE hnd
-) {
-    JoystickImpl *This = (JoystickImpl *)iface;
-
-    TRACE("(this=%p,%p)\n",This,hnd);
-    This->hEvent = hnd;
-    return DI_OK;
-}
-
 static HRESULT WINAPI JoystickAImpl_GetCapabilities(
 	LPDIRECTINPUTDEVICE8A iface,
 	LPDIDEVCAPS lpDIDevCaps)
@@ -1663,7 +1648,7 @@ static const IDirectInputDevice8AVtbl JoystickAvt =
 	JoystickAImpl_GetDeviceState,
 	JoystickAImpl_GetDeviceData,
 	JoystickAImpl_SetDataFormat,
-	JoystickAImpl_SetEventNotification,
+	IDirectInputDevice2AImpl_SetEventNotification,
 	IDirectInputDevice2AImpl_SetCooperativeLevel,
 	JoystickAImpl_GetObjectInfo,
 	JoystickAImpl_GetDeviceInfo,
@@ -1705,7 +1690,7 @@ static const IDirectInputDevice8WVtbl SysJoystickWvt =
 	XCAST(GetDeviceState)JoystickAImpl_GetDeviceState,
 	XCAST(GetDeviceData)JoystickAImpl_GetDeviceData,
 	XCAST(SetDataFormat)JoystickAImpl_SetDataFormat,
-	XCAST(SetEventNotification)JoystickAImpl_SetEventNotification,
+	XCAST(SetEventNotification)IDirectInputDevice2AImpl_SetEventNotification,
 	XCAST(SetCooperativeLevel)IDirectInputDevice2AImpl_SetCooperativeLevel,
 	IDirectInputDevice2WImpl_GetObjectInfo,
 	JoystickWImpl_GetDeviceInfo,
