@@ -118,9 +118,8 @@ struct JoyDev {
 
 struct JoystickImpl
 {
-        const void                     *lpVtbl;
-        LONG                            ref;
-        GUID                            guid;
+        struct IDirectInputDevice2AImpl base;
+
         struct JoyDev                  *joydev;
 
 	/* The 'parent' DInput */
@@ -138,7 +137,6 @@ struct JoystickImpl
 	LPDIDATAFORMAT			df;
 	DataFormat			*transform;	/* wine to user format converter */
 	int				*offsets;	/* object offsets */
-        HANDLE				hEvent;
         LPDIDEVICEOBJECTDATA 		data_queue;
         int				queue_head, queue_tail, queue_len;
 	BOOL				overflow;
@@ -373,15 +371,15 @@ static JoystickImpl *alloc_device(REFGUID rguid, const void *jvt, IDirectInputIm
     return NULL;
   }
 
-  newDevice->lpVtbl = jvt;
-  newDevice->ref = 1;
+  newDevice->base.lpVtbl = jvt;
+  newDevice->base.ref = 1;
+  memcpy(&newDevice->base.guid, rguid, sizeof(*rguid));
   newDevice->joyfd = -1;
   newDevice->dinput = dinput;
   newDevice->joydev = joydev;
 #ifdef HAVE_STRUCT_FF_EFFECT_DIRECTION
   newDevice->ff_state = FF_STATUS_STOPPED;
 #endif
-  memcpy(&(newDevice->guid),rguid,sizeof(*rguid));
   for (i=0;i<ABS_MAX;i++) {
     /* apps expect the range to be the same they would get from the
      * GetProperty/range method */
@@ -522,7 +520,7 @@ static ULONG WINAPI JoystickAImpl_Release(LPDIRECTINPUTDEVICE8A iface)
 	JoystickImpl *This = (JoystickImpl *)iface;
 	ULONG ref;
 
-	ref = InterlockedDecrement(&(This->ref));
+	ref = InterlockedDecrement(&This->base.ref);
 	if (ref)
 		return ref;
 
@@ -1168,19 +1166,6 @@ static HRESULT WINAPI JoystickAImpl_SetProperty(LPDIRECTINPUTDEVICE8A iface,
   return 0;
 }
 
-/******************************************************************************
-  *     SetEventNotification : specifies event to be sent on state change
-  */
-static HRESULT WINAPI JoystickAImpl_SetEventNotification(
-	LPDIRECTINPUTDEVICE8A iface, HANDLE hnd
-) {
-    JoystickImpl *This = (JoystickImpl *)iface;
-
-    TRACE("(this=%p,%p)\n",This,hnd);
-    This->hEvent = hnd;
-    return DI_OK;
-}
-
 static HRESULT WINAPI JoystickAImpl_GetCapabilities(
 	LPDIRECTINPUTDEVICE8A iface,
 	LPDIDEVCAPS lpDIDevCaps)
@@ -1785,7 +1770,7 @@ static HRESULT WINAPI JoystickAImpl_EnumCreatedEffectObjects(
 	return DIERR_INVALIDPARAM;
 
     if (dwFlags != 0)
-	FIXME("Flags specified, but no flags exist yet (DX9)!");
+	FIXME("Flags specified, but no flags exist yet (DX9)!\n");
 
     while (itr) {
 	(*lpCallback)(itr->ref, pvRef);
@@ -1809,7 +1794,7 @@ static const IDirectInputDevice8AVtbl JoystickAvt =
 	JoystickAImpl_GetDeviceState,
 	JoystickAImpl_GetDeviceData,
 	JoystickAImpl_SetDataFormat,
-	JoystickAImpl_SetEventNotification,
+	IDirectInputDevice2AImpl_SetEventNotification,
 	IDirectInputDevice2AImpl_SetCooperativeLevel,
 	IDirectInputDevice2AImpl_GetObjectInfo,
 	IDirectInputDevice2AImpl_GetDeviceInfo,
@@ -1851,7 +1836,7 @@ static const IDirectInputDevice8WVtbl JoystickWvt =
 	XCAST(GetDeviceState)JoystickAImpl_GetDeviceState,
 	XCAST(GetDeviceData)JoystickAImpl_GetDeviceData,
 	XCAST(SetDataFormat)JoystickAImpl_SetDataFormat,
-	XCAST(SetEventNotification)JoystickAImpl_SetEventNotification,
+	XCAST(SetEventNotification)IDirectInputDevice2AImpl_SetEventNotification,
 	XCAST(SetCooperativeLevel)IDirectInputDevice2AImpl_SetCooperativeLevel,
 	IDirectInputDevice2WImpl_GetObjectInfo,
 	IDirectInputDevice2WImpl_GetDeviceInfo,
