@@ -86,11 +86,13 @@ struct HTMLDocument {
     IOleInPlaceSite *ipsite;
     IOleInPlaceFrame *frame;
 
+    BSCallback *bscallback;
+
     HWND hwnd;
-    HWND hidden_hwnd;
     HWND tooltips_hwnd;
 
     USERMODE usermode;
+    READYSTATE readystate;
     BOOL in_place_active;
     BOOL ui_active;
     BOOL window_active;
@@ -175,6 +177,9 @@ struct BSCallback {
     nsISupports *nscontext;
 
     IMoniker *mon;
+    IBinding *binding;
+
+    HTMLDocument *doc;
 
     nsProtocolStream *nsstream;
 };
@@ -313,10 +318,11 @@ void nsAString_Finish(nsAString*);
 
 nsIInputStream *create_nsstream(const char*,PRInt32);
 nsICommandParams *create_nscommand_params(void);
+void nsnode_to_nsstring(nsIDOMNode*,nsAString*);
 
-BSCallback *create_bscallback(HTMLDocument*,IMoniker*);
+BSCallback *create_bscallback(IMoniker*);
 HRESULT start_binding(BSCallback*);
-void create_hidden_hwnd(HTMLDocument*);
+void set_document_bscallback(HTMLDocument*,BSCallback*);
 
 IHlink *Hlink_Create(void);
 IHTMLSelectionObject *HTMLSelectionObject_Create(nsISelection*);
@@ -340,6 +346,30 @@ void release_nodes(HTMLDocument*);
 
 void install_wine_gecko(void);
 
+extern DWORD mshtml_tls;
+
+typedef struct task_t {
+    HTMLDocument *doc;
+
+    enum {
+        TASK_SETDOWNLOADSTATE,
+        TASK_PARSECOMPLETE
+    } task_id;
+
+    struct task_t *next;
+} task_t;
+
+typedef struct {
+    HWND thread_hwnd;
+    task_t *task_queue_head;
+    task_t *task_queue_tail;
+} thread_data_t;
+
+thread_data_t *get_thread_data(BOOL);
+HWND get_thread_hwnd(void);
+void push_task(task_t*);
+void remove_doc_tasks(HTMLDocument*);
+
 DEFINE_GUID(CLSID_AboutProtocol, 0x3050F406, 0x98B5, 0x11CF, 0xBB,0x82, 0x00,0xAA,0x00,0xBD,0xCE,0x0B);
 DEFINE_GUID(CLSID_JSProtocol, 0x3050F3B2, 0x98B5, 0x11CF, 0xBB,0x82, 0x00,0xAA,0x00,0xBD,0xCE,0x0B);
 DEFINE_GUID(CLSID_MailtoProtocol, 0x3050F3DA, 0x98B5, 0x11CF, 0xBB,0x82, 0x00,0xAA,0x00,0xBD,0xCE,0x0B);
@@ -359,6 +389,11 @@ static inline void *mshtml_alloc(size_t len)
     return HeapAlloc(GetProcessHeap(), 0, len);
 }
 
+static inline void *mshtml_alloc_zero(size_t len)
+{
+    return HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, len);
+}
+
 static inline void *mshtml_realloc(void *mem, size_t len)
 {
     return HeapReAlloc(GetProcessHeap(), 0, mem, len);
