@@ -27,15 +27,17 @@
 #include "windef.h"
 #include "winbase.h"
 #include "winerror.h"
-#include "wine/debug.h"
 #include "msi.h"
 #include "msiquery.h"
 #include "objbase.h"
 #include "objidl.h"
-#include "msipriv.h"
 #include "winnls.h"
-
+#include "msipriv.h"
 #include "query.h"
+#include "assert.h"
+
+#include "wine/debug.h"
+#include "wine/unicode.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(msidb);
 
@@ -80,7 +82,7 @@ static const WCHAR szStringPool[] = {
 
 static UINT table_get_column_info( MSIDATABASE *db, LPCWSTR name,
        MSICOLUMNINFO **pcols, UINT *pcount );
-static UINT get_tablecolumns( MSIDATABASE *db, 
+static UINT get_tablecolumns( MSIDATABASE *db,
        LPCWSTR szTableName, MSICOLUMNINFO *colinfo, UINT *sz);
 static void msi_free_colinfo( MSICOLUMNINFO *colinfo, UINT count );
 
@@ -925,12 +927,14 @@ static LPWSTR msi_makestring( MSIDATABASE *db, UINT stringid)
     return strdupW(msi_string_lookup_id( db->strings, stringid ));
 }
 
-static UINT get_tablecolumns( MSIDATABASE *db, 
+static UINT get_tablecolumns( MSIDATABASE *db,
        LPCWSTR szTableName, MSICOLUMNINFO *colinfo, UINT *sz)
 {
     UINT r, i, n=0, table_id, count, maxcount = *sz;
     MSITABLE *table = NULL;
 
+    TRACE("%s\n", debugstr_w(szTableName));
+
     /* first check if there is a default table with that name */
     r = get_defaulttablecolumns( szTableName, colinfo, sz );
     if( ( r == ERROR_SUCCESS ) && *sz )
@@ -953,6 +957,8 @@ static UINT get_tablecolumns( MSIDATABASE *db,
 
     TRACE("Table id is %d, row count is %d\n", table_id, table->row_count);
 
+    /* if maxcount is non-zero, assume it's exactly right for this table */
+    memset( colinfo, 0, maxcount*sizeof(*colinfo) );
     count = table->row_count;
     for( i=0; i<count; i++ )
     {
@@ -961,32 +967,53 @@ static UINT get_tablecolumns( MSIDATABASE *db,
         if( colinfo )
         {
             UINT id = table->data[ i ] [ 2 ];
-            colinfo[n].tablename = msi_makestring( db, table_id );
-            colinfo[n].number = table->data[ i ][ 1 ] - (1<<15);
-            colinfo[n].colname = msi_makestring( db, id );
-            colinfo[n].type = table->data[ i ] [ 3 ] ^ 0x8000;
-            colinfo[n].hash_table = NULL;
-            /* this assumes that columns are in order in the table */
-            if( n )
-                colinfo[n].offset = colinfo[n-1].offset
-                                  + bytes_per_column( &colinfo[n-1] );
-            else
-                colinfo[n].offset = 0;
-            TRACE("table %s column %d is [%s] (%d) with type %08x "
-                  "offset %d at row %d\n", debugstr_w(szTableName),
-                   colinfo[n].number, debugstr_w(colinfo[n].colname),
-                   id, colinfo[n].type, colinfo[n].offset, i);
-            if( n != (colinfo[n].number-1) )
+            UINT col = table->data[ i ][ 1 ] - (1<<15);
+
+            /* check the column number is in range */
+            if (col<1 || col>maxcount)
             {
-                ERR("oops. data in the _Columns table isn't in the right "
-                    "order for table %s\n", debugstr_w(szTableName));
-                msi_free_colinfo(colinfo, n+1 );
-                return ERROR_FUNCTION_FAILED;
+                ERR("column %d out of range\n", col);
+                continue;
             }
+
+            /* check if this column was already set */
+            if (colinfo[ col - 1 ].number)
+            {
+                ERR("duplicate column %d\n", col);
+                continue;
+            }
+
+            colinfo[ col - 1 ].tablename = msi_makestring( db, table_id );
+            colinfo[ col - 1 ].number = col;
+            colinfo[ col - 1 ].colname = msi_makestring( db, id );
+            colinfo[ col - 1 ].type = table->data[ i ] [ 3 ] - (1<<15);
+            colinfo[ col - 1 ].offset = 0;
+            colinfo[ col - 1 ].hash_table = NULL;
         }
         n++;
-        if( colinfo && ( n >= maxcount ) )
-            break;
+    }
+
+    TRACE("%s has %d columns\n", debugstr_w(szTableName), n);
+
+    if (maxcount && n != maxcount)
+    {
+        ERR("missing column in table %s\n", debugstr_w(szTableName));
+        msi_free_colinfo(colinfo, maxcount );
+        return ERROR_FUNCTION_FAILED;
+    }
+
+    /* calculate the offsets */
+    for( i=0; maxcount && (i<maxcount); i++ )
+    {
+         assert( (i+1) == colinfo[ i ].number );
+         if (i)
+             colinfo[i].offset = colinfo[ i - 1 ].offset
+                               + bytes_per_column( &colinfo[ i - 1 ] );
+         else
+             colinfo[i].offset = 0;
+         TRACE("column %d is [%s] with type %08x ofs %d\n",
+               colinfo[i].number, debugstr_w(colinfo[i].colname),
+               colinfo[i].type, colinfo[i].offset);
     }
     *sz = n;
 
@@ -1074,7 +1101,7 @@ static UINT TABLE_fetch_int( struct tagMSIVIEW *view, UINT row, UINT col, UINT *
     {
     case 4:
         offset = tv->columns[col-1].offset/2;
-        *val = tv->table->data[row][offset] + 
+        *val = tv->table->data[row][offset] +
                (tv->table->data[row][offset + 1] << 16);
         break;
     case 2:
@@ -1104,6 +1131,7 @@ static UINT TABLE_fetch_stream( struct tagMSIVIEW *view, UINT row, UINT col, ISt
     LPWSTR full_name;
     DWORD len;
     static const WCHAR szDot[] = { '.', 0 };
+    WCHAR number[0x20];
 
     if( !view->ops->fetch_int )
         return ERROR_INVALID_PARAMETER;
@@ -1118,15 +1146,31 @@ static UINT TABLE_fetch_stream( struct tagMSIVIEW *view, UINT row, UINT col, ISt
     if( r != ERROR_SUCCESS )
         return r;
 
-    /* now get the column with the name of the stream */
-    r = view->ops->fetch_int( view, row, ival, &refcol );
-    if( r != ERROR_SUCCESS )
-        return r;
+    /* check the column value is in range */
+    if (ival < 0 || ival > tv->num_cols || ival == col)
+    {
+        ERR("bad column ref (%u) for stream\n", ival);
+        return ERROR_FUNCTION_FAILED;
+    }
 
-    /* lookup the string value from the string table */
-    sval = msi_string_lookup_id( tv->db->strings, refcol );
-    if( !sval )
-        return ERROR_INVALID_PARAMETER;
+    if ( tv->columns[ival - 1].type & MSITYPE_STRING )
+    {
+        /* now get the column with the name of the stream */
+        r = view->ops->fetch_int( view, row, ival, &refcol );
+        if ( r != ERROR_SUCCESS )
+            return r;
+
+        /* lookup the string value from the string table */
+        sval = msi_string_lookup_id( tv->db->strings, refcol );
+        if ( !sval )
+            return ERROR_INVALID_PARAMETER;
+    }
+    else
+    {
+        static const WCHAR fmt[] = { '%','d',0 };
+        sprintfW( number, fmt, ival );
+        sval = number;
+    }
 
     len = lstrlenW( tv->name ) + 2 + lstrlenW( sval );
     full_name = msi_alloc( len*sizeof(WCHAR) );
@@ -1142,9 +1186,8 @@ static UINT TABLE_fetch_stream( struct tagMSIVIEW *view, UINT row, UINT col, ISt
     return r;
 }
 
-static UINT TABLE_set_int( struct tagMSIVIEW *view, UINT row, UINT col, UINT val )
+static UINT TABLE_set_int( MSITABLEVIEW *tv, UINT row, UINT col, UINT val )
 {
-    MSITABLEVIEW *tv = (MSITABLEVIEW*)view;
     UINT offset, n;
 
     if( !tv->table )
@@ -1179,6 +1222,61 @@ static UINT TABLE_set_int( struct tagMSIVIEW *view, UINT row, UINT col, UINT val
     return ERROR_SUCCESS;
 }
 
+static UINT TABLE_set_row( struct tagMSIVIEW *view, UINT row, MSIRECORD *rec, UINT mask )
+{
+    MSITABLEVIEW *tv = (MSITABLEVIEW*)view;
+    UINT i, val, r = ERROR_SUCCESS;
+
+    if ( !tv->table )
+        return ERROR_INVALID_PARAMETER;
+
+    /* test if any of the mask bits are invalid */
+    if ( mask >= (1<<tv->num_cols) )
+        return ERROR_INVALID_PARAMETER;
+
+    for ( i = 0; i < tv->num_cols; i++ )
+    {
+        /* only update the fields specified in the mask */
+        if ( !(mask&(1<<i)) )
+            continue;
+
+        /* FIXME: should we allow updating keys? */
+
+        val = 0;
+        if ( !MSI_RecordIsNull( rec, i + 1 ) )
+        {
+            if ( MSITYPE_IS_BINARY(tv->columns[ i ].type) )
+            {
+                val = 1; /* refers to the first key column */
+            }
+            else if ( tv->columns[i].type & MSITYPE_STRING )
+            {
+                LPCWSTR sval = MSI_RecordGetString( rec, i + 1 );
+                val = msi_addstringW( tv->db->strings, 0, sval, -1, 1 );
+            }
+            else if ( 2 == bytes_per_column( &tv->columns[ i ] ) )
+            {
+                val = 0x8000 + MSI_RecordGetInteger( rec, i + 1 );
+                if ( val & 0xffff0000 )
+                {
+                    ERR("field %u value %d out of range\n", i+1, val - 0x8000 );
+                    return ERROR_FUNCTION_FAILED;
+                }
+            }
+            else
+            {
+                INT ival = MSI_RecordGetInteger( rec, i + 1 );
+                val = ival ^ 0x80000000;
+            }
+        }
+
+        r = TABLE_set_int( tv, row, i+1, val );
+        if ( r != ERROR_SUCCESS )
+            break;
+    }
+    return r;
+}
+
 static UINT table_create_new_row( struct tagMSIVIEW *view, UINT *num )
 {
     MSITABLEVIEW *tv = (MSITABLEVIEW*)view;
@@ -1293,7 +1391,9 @@ static UINT table_validate_new( MSITABLEVIEW *tv, MSIRECORD *rec )
         if ( tv->columns[i].type & MSITYPE_NULLABLE )
             continue;
 
-        if ( tv->columns[i].type & MSITYPE_STRING )
+        if ( MSITYPE_IS_BINARY(tv->columns[i].type) )
+            TRACE("skipping binary column\n");
+        else if ( tv->columns[i].type & MSITYPE_STRING )
         {
             LPCWSTR str;
 
@@ -1319,41 +1419,6 @@ static UINT table_validate_new( MSITABLEVIEW *tv, MSIRECORD *rec )
     return ERROR_SUCCESS;
 }
 
-static UINT msi_table_modify_row( MSITABLEVIEW *tv, MSIRECORD *rec,
-                                  UINT row, UINT mask )
-{
-    UINT i, val, r = ERROR_SUCCESS;
-
-    TRACE("%p %p %u %08x\n", tv, rec, row, mask );
-
-    for( i = 0; i < tv->num_cols; i++ )
-    {
-        /* set keys or values specified in the mask */
-        if( (~tv->columns[i].type & MSITYPE_KEY) && (~mask & (1<<i)) )
-            continue;
-
-        if( (tv->columns[i].type & MSITYPE_STRING) &&
-            ! MSITYPE_IS_BINARY(tv->columns[i].type) )
-        {
-            const WCHAR *str = MSI_RecordGetString( rec, i+1 );
-            val = msi_addstringW( tv->db->strings, 0, str, -1, 1 );
-        }
-        else
-        {
-            val = MSI_RecordGetInteger( rec, i+1 );
-            if ( 2 == bytes_per_column( &tv->columns[i] ) )
-                val ^= 0x8000;
-            else
-                val ^= 0x80000000;
-        }
-        r = TABLE_set_int( &tv->view, row, i+1, val );
-        if( r )
-            break;
-    }
-
-    return r;
-}
-
 static UINT TABLE_insert_row( struct tagMSIVIEW *view, MSIRECORD *rec )
 {
     MSITABLEVIEW *tv = (MSITABLEVIEW*)view;
@@ -1371,7 +1436,7 @@ static UINT TABLE_insert_row( struct tagMSIVIEW *view, MSIRECORD *rec )
     if( r != ERROR_SUCCESS )
         return r;
 
-    return msi_table_modify_row( tv, rec, row, ~0 );
+    return TABLE_set_row( view, row, rec, (1<<tv->num_cols) - 1 );
 }
 
 static UINT TABLE_modify( struct tagMSIVIEW *view, MSIMODIFY eModifyMode,
@@ -1540,7 +1605,7 @@ static const MSIVIEWOPS table_ops =
 {
     TABLE_fetch_int,
     TABLE_fetch_stream,
-    TABLE_set_int,
+    TABLE_set_row,
     TABLE_insert_row,
     TABLE_execute,
     TABLE_close,
@@ -1659,7 +1724,7 @@ static MSIRECORD *msi_get_transform_record( MSITABLEVIEW *tv, string_table *st,
     if( !rec )
         return rec;
 
-    TRACE("row -> \n");
+    TRACE("row ->\n");
     for( i=0; i<tv->num_cols; i++ )
     {
         UINT n = bytes_per_column( &columns[i] );
@@ -1826,8 +1891,9 @@ static UINT msi_table_find_row( MSITABLEVIEW *tv, MSIRECORD *rec, UINT *row )
 static UINT msi_delete_row( MSITABLEVIEW *tv, UINT row )
 {
     UINT i;
+
     for( i=1; i<=tv->num_cols; i++ )
-        tv->view.ops->set_int( &tv->view, row, i, 0 );
+        TABLE_set_int( tv, row, i, 0 );
     return ERROR_SUCCESS;
 }
 
@@ -1840,7 +1906,9 @@ static UINT msi_table_load_transform( MSIDATABASE *db, IStorage *stg,
     UINT r, n, sz, i, mask;
     MSIRECORD *rec = NULL;
     UINT colcol = 0;
+    WCHAR coltable[32];
 
+    coltable[0] = 0;
     TRACE("%p %p %p %s\n", db, stg, st, debugstr_w(name) );
 
     /* read the transform data */
@@ -1917,10 +1985,20 @@ static UINT msi_table_load_transform( MSIDATABASE *db, IStorage *stg,
                  */
                 if (!lstrcmpW(name, szColumns))
                 {
-                    if ( MSI_RecordIsNull( rec, 2 ) )
-                        MSI_RecordSetInteger( rec, 2, ++colcol );
-                    else
-                        ERR("_Columns has non-null data...\n");
+                    WCHAR table[32];
+                    DWORD sz = 32;
+
+                    MSI_RecordGetStringW( rec, 1, table, &sz );
+
+                    /* reset the column number on a new table */
+                    if ( lstrcmpW(coltable, table) )
+                    {
+                        colcol = 0;
+                        lstrcpyW( coltable, table );
+                    }
+
+                    /* fix nul column numbers */
+                    MSI_RecordSetInteger( rec, 2, ++colcol );
                 }
 
                 r = TABLE_insert_row( &tv->view, rec );
@@ -1936,12 +2014,12 @@ static UINT msi_table_load_transform( MSIDATABASE *db, IStorage *stg,
                     ERR("no matching row to transform\n");
                 else if ( mask )
                 {
-                    TRACE("modifying row [%d]: \n", row);
-                    msi_table_modify_row( tv, rec, row, mask );
+                    TRACE("modifying row [%d]:\n", row);
+                    TABLE_set_row( &tv->view, row, rec, mask );
                 }
                 else
                 {
-                    TRACE("deleting row [%d]: \n", row);
+                    TRACE("deleting row [%d]:\n", row);
                     msi_delete_row( tv, row );
                 }
             }
