@@ -34,35 +34,6 @@ CHAR PROG_FILES_DIR[MAX_PATH];
 
 /* msi database data */
 
-static const CHAR admin_exec_seq_dat[] = "Action\tCondition\tSequence\n"
-                                         "s72\tS255\tI2\n"
-                                         "AdminExecuteSequence\tAction\n"
-                                         "CostFinalize\t\t1000\n"
-                                         "CostInitialize\t\t800\n"
-                                         "FileCost\t\t900\n"
-                                         "InstallAdminPackage\t\t3900\n"
-                                         "InstallFiles\t\t4000\n"
-                                         "InstallFinalize\t\t6600\n"
-                                         "InstallInitialize\t\t1500\n"
-                                         "InstallValidate\t\t1400";
-
-static const CHAR advt_exec_seq_dat[] = "Action\tCondition\tSequence\n"
-                                        "s72\tS255\tI2\n"
-                                        "AdvtExecuteSequence\tAction\n"
-                                        "CostFinalize\t\t1000\n"
-                                        "CostInitialize\t\t800\n"
-                                        "CreateShortcuts\t\t4500\n"
-                                        "InstallFinalize\t\t6600\n"
-                                        "InstallInitialize\t\t1500\n"
-                                        "InstallValidate\t\t1400\n"
-                                        "PublishComponents\t\t6200\n"
-                                        "PublishFeatures\t\t6300\n"
-                                        "PublishProduct\t\t6400\n"
-                                        "RegisterClassInfo\t\t4600\n"
-                                        "RegisterExtensionInfo\t\t4700\n"
-                                        "RegisterMIMEInfo\t\t4900\n"
-                                        "RegisterProgIdInfo\t\t4800";
-
 static const CHAR component_dat[] = "Component\tComponentId\tDirectory_\tAttributes\tCondition\tKeyPath\n"
                                     "s72\tS38\ts72\ti2\tS255\tS72\n"
                                     "Component\tComponent\n"
@@ -71,7 +42,9 @@ static const CHAR component_dat[] = "Component\tComponentId\tDirectory_\tAttribu
                                     "One\t{783B242E-E185-4A56-AF86-C09815EC053C}\tMSITESTDIR\t2\t\tone.txt\n"
                                     "Three\t{010B6ADD-B27D-4EDD-9B3D-34C4F7D61684}\tCHANGEDDIR\t2\t\tthree.txt\n"
                                     "Two\t{BF03D1A6-20DA-4A65-82F3-6CAC995915CE}\tFIRSTDIR\t2\t\ttwo.txt\n"
-                                    "dangler\t{6091DF25-EF96-45F1-B8E9-A9B1420C7A3C}\tTARGETDIR\t4\t\tregdata";
+                                    "dangler\t{6091DF25-EF96-45F1-B8E9-A9B1420C7A3C}\tTARGETDIR\t4\t\tregdata\n"
+                                    "component\t\tMSITESTDIR\t0\t1\tfile\n"
+                                    "service_comp\t\tMSITESTDIR\t0\t1\tservice_file";
 
 static const CHAR directory_dat[] = "Directory\tDirectory_Parent\tDefaultDir\n"
                                     "s72\tS72\tl255\n"
@@ -91,7 +64,9 @@ static const CHAR feature_dat[] = "Feature\tFeature_Parent\tTitle\tDescription\t
                                   "Four\t\tFour\tThe Four Feature\t4\t3\tCABOUTDIR\t0\n"
                                   "One\t\tOne\tThe One Feature\t1\t3\tMSITESTDIR\t0\n"
                                   "Three\t\tThree\tThe Three Feature\t3\t3\tCHANGEDDIR\t0\n"
-                                  "Two\t\tTwo\tThe Two Feature\t2\t3\tFIRSTDIR\t0";
+                                  "Two\t\tTwo\tThe Two Feature\t2\t3\tFIRSTDIR\t0\n"
+                                  "feature\t\t\t\t2\t1\tTARGETDIR\t0\n"
+                                  "service_feature\t\t\t\t2\t1\tTARGETDIR\t0";
 
 static const CHAR feature_comp_dat[] = "Feature_\tComponent_\n"
                                        "s38\ts72\n"
@@ -100,7 +75,9 @@ static const CHAR feature_comp_dat[] = "Feature_\tComponent_\n"
                                        "Four\tFour\n"
                                        "One\tOne\n"
                                        "Three\tThree\n"
-                                       "Two\tTwo";
+                                       "Two\tTwo\n"
+                                       "feature\tcomponent\n"
+                                       "service_feature\tservice_comp\n";
 
 static const CHAR file_dat[] = "File\tComponent_\tFileName\tFileSize\tVersion\tLanguage\tAttributes\tSequence\n"
                                "s72\ts72\tl255\ti4\tS72\tS20\tI2\ti2\n"
@@ -109,7 +86,9 @@ static const CHAR file_dat[] = "File\tComponent_\tFileName\tFileSize\tVersion\tL
                                "four.txt\tFour\tfour.txt\t1000\t\t\t16384\t4\n"
                                "one.txt\tOne\tone.txt\t1000\t\t\t0\t1\n"
                                "three.txt\tThree\tthree.txt\t1000\t\t\t0\t3\n"
-                               "two.txt\tTwo\ttwo.txt\t1000\t\t\t0\t2";
+                               "two.txt\tTwo\ttwo.txt\t1000\t\t\t0\t2\n"
+                               "file\tcomponent\tfilename\t100\t\t\t8192\t1\n"
+                               "service_file\tservice_comp\tservice.exe\t100\t\t\t8192\t1";
 
 static const CHAR install_exec_seq_dat[] = "Action\tCondition\tSequence\n"
                                            "s72\tS255\tI2\n"
@@ -119,11 +98,12 @@ static const CHAR install_exec_seq_dat[] = "Action\tCondition\tSequence\n"
                                            "CostInitialize\t\t800\n"
                                            "FileCost\t\t900\n"
                                            "InstallFiles\t\t4000\n"
+                                           "InstallServices\t\t5000\n"
                                            "InstallFinalize\t\t6600\n"
                                            "InstallInitialize\t\t1500\n"
                                            "InstallValidate\t\t1400\n"
                                            "LaunchConditions\t\t100\n"
-                                           "WriteRegistryValues\t\t5000";
+                                           "WriteRegistryValues\tSourceDir And SOURCEDIR\t5000";
 
 static const CHAR media_dat[] = "DiskId\tLastSequence\tDiskPrompt\tCabinet\tVolumeLabel\tSource\n"
                                 "i2\ti4\tL64\tS255\tS32\tS72\n"
@@ -153,7 +133,49 @@ static const CHAR registry_dat[] = "Registry\tRoot\tKey\tName\tValue\tComponent_
                                    "Registry\tRegistry\n"
                                    "Apples\t2\tSOFTWARE\\Wine\\msitest\tName\timaname\tOne\n"
                                    "Oranges\t2\tSOFTWARE\\Wine\\msitest\tnumber\t#314\tTwo\n"
-                                   "regdata\t2\tSOFTWARE\\Wine\\msitest\tblah\tbad\tdangler";
+                                   "regdata\t2\tSOFTWARE\\Wine\\msitest\tblah\tbad\tdangler\n"
+                                   "OrderTest\t2\tSOFTWARE\\Wine\\msitest\tOrderTestName\tOrderTestValue\tcomponent";
+
+static const CHAR service_install_dat[] = "ServiceInstall\tName\tDisplayName\tServiceType\tStartType\tErrorControl\t"
+                                          "LoadOrderGroup\tDependencies\tStartName\tPassword\tArguments\tComponent_\tDescription\n"
+                                          "s72\ts255\tL255\ti4\ti4\ti4\tS255\tS255\tS255\tS255\tS255\ts72\tL255\n"
+                                          "ServiceInstall\tServiceInstall\n"
+                                          "TestService\tTestService\tTestService\t2\t3\t0\t\t\tTestService\t\t\tservice_comp\t\t";
+
+static const CHAR service_control_dat[] = "ServiceControl\tName\tEvent\tArguments\tWait\tComponent_\n"
+                                          "s72\tl255\ti2\tL255\tI2\ts72\n"
+                                          "ServiceControl\tServiceControl\n"
+                                          "ServiceControl\tTestService\t8\t\t0\tservice_comp";
+
+/* tables for test_continuouscabs */
+static const CHAR cc_component_dat[] = "Component\tComponentId\tDirectory_\tAttributes\tCondition\tKeyPath\n"
+                                       "s72\tS38\ts72\ti2\tS255\tS72\n"
+                                       "Component\tComponent\n"
+                                       "maximus\t\tMSITESTDIR\t0\t1\tmaximus\n"
+                                       "augustus\t\tMSITESTDIR\t0\t1\taugustus";
+
+static const CHAR cc_feature_dat[] = "Feature\tFeature_Parent\tTitle\tDescription\tDisplay\tLevel\tDirectory_\tAttributes\n"
+                                     "s38\tS38\tL64\tL255\tI2\ti2\tS72\ti2\n"
+                                     "Feature\tFeature\n"
+                                     "feature\t\t\t\t2\t1\tTARGETDIR\t0";
+
+static const CHAR cc_feature_comp_dat[] = "Feature_\tComponent_\n"
+                                          "s38\ts72\n"
+                                          "FeatureComponents\tFeature_\tComponent_\n"
+                                          "feature\tmaximus\n"
+                                          "feature\taugustus";
+
+static const CHAR cc_file_dat[] = "File\tComponent_\tFileName\tFileSize\tVersion\tLanguage\tAttributes\tSequence\n"
+                                  "s72\ts72\tl255\ti4\tS72\tS20\tI2\ti2\n"
+                                  "File\tFile\n"
+                                  "maximus\tmaximus\tmaximus\t500\t\t\t16384\t1\n"
+                                  "augustus\taugustus\taugustus\t50000\t\t\t16384\t1";
+
+static const CHAR cc_media_dat[] = "DiskId\tLastSequence\tDiskPrompt\tCabinet\tVolumeLabel\tSource\n"
+                                   "i2\ti4\tL64\tS255\tS32\tS72\n"
+                                   "Media\tDiskId\n"
+                                   "1\t10\t\ttest1.cab\tDISK1\t\n"
+                                   "2\t2\t\ttest2.cab\tDISK2\t\n";
 
 typedef struct _msi_table
 {
@@ -166,8 +188,6 @@ typedef struct _msi_table
 
 static const msi_table tables[] =
 {
-    ADD_TABLE(admin_exec_seq),
-    ADD_TABLE(advt_exec_seq),
     ADD_TABLE(component),
     ADD_TABLE(directory),
     ADD_TABLE(feature),
@@ -176,44 +196,29 @@ static const msi_table tables[] =
     ADD_TABLE(install_exec_seq),
     ADD_TABLE(media),
     ADD_TABLE(property),
-    ADD_TABLE(registry)
+    ADD_TABLE(registry),
+    ADD_TABLE(service_install),
+    ADD_TABLE(service_control)
+};
+
+static const msi_table cc_tables[] =
+{
+    ADD_TABLE(cc_component),
+    ADD_TABLE(directory),
+    ADD_TABLE(cc_feature),
+    ADD_TABLE(cc_feature_comp),
+    ADD_TABLE(cc_file),
+    ADD_TABLE(install_exec_seq),
+    ADD_TABLE(cc_media),
+    ADD_TABLE(property),
 };
 
 /* cabinet definitions */
 
 /* make the max size large so there is only one cab file */
-#define MEDIA_SIZE          999999999
+#define MEDIA_SIZE          0x7FFFFFFF
 #define FOLDER_THRESHOLD    900000
 
-/* The following defintions were copied from dlls/cabinet/cabinet.h
- * because they are undocumented in windows.
- */
-
-/* EXTRACTdest flags */
-#define EXTRACT_FILLFILELIST  0x00000001
-#define EXTRACT_EXTRACTFILES  0x00000002
-
-struct ExtractFileList {
-    LPSTR  filename;
-    struct ExtractFileList *next;
-    BOOL   unknown;  /* always 1L */
-};
-
-/* the first parameter of the function extract */
-typedef struct {
-    long   result1;          /* 0x000 */
-    long   unknown1[3];      /* 0x004 */
-    struct ExtractFileList *filelist; /* 0x010 */
-    long   filecount;        /* 0x014 */
-    long   flags;            /* 0x018 */
-    char   directory[0x104]; /* 0x01c */
-    char   lastfile[0x20c];  /* 0x120 */
-} EXTRACTDEST;
-
-/* cabinet function pointers */
-HMODULE hCabinet;
-static HRESULT (WINAPI *pExtract)(EXTRACTDEST*, LPCSTR);
-
 /* the FCI callbacks */
 
 static void *mem_alloc(ULONG cb)
@@ -228,6 +233,7 @@ static void mem_free(void *memory)
 
 static BOOL get_next_cabinet(PCCAB pccab, ULONG  cbPrevCab, void *pv)
 {
+    sprintf(pccab->szCab, pv, pccab->iCab);
     return TRUE;
 }
 
@@ -373,42 +379,43 @@ static INT_PTR get_open_info(char *pszName, USHORT *pdate, USHORT *ptime,
     return (INT_PTR)handle;
 }
 
-static void add_file(HFCI hfci, char *file)
+static BOOL add_file(HFCI hfci, const char *file, TCOMP compress)
 {
     char path[MAX_PATH];
-    BOOL res;
+    char filename[MAX_PATH];
 
     lstrcpyA(path, CURR_DIR);
     lstrcatA(path, "\\");
     lstrcatA(path, file);
 
-    res = FCIAddFile(hfci, path, file, FALSE, get_next_cabinet, progress,
-                     get_open_info, tcompTYPE_MSZIP);
-    ok(res, "Expected FCIAddFile to succeed\n");
+    lstrcpyA(filename, file);
+
+    return FCIAddFile(hfci, path, filename, FALSE, get_next_cabinet,
+                      progress, get_open_info, compress);
 }
 
-static void set_cab_parameters(PCCAB pCabParams, const CHAR *name)
+static void set_cab_parameters(PCCAB pCabParams, const CHAR *name, DWORD max_size)
 {
     ZeroMemory(pCabParams, sizeof(CCAB));
 
-    pCabParams->cb = MEDIA_SIZE;
+    pCabParams->cb = max_size;
     pCabParams->cbFolderThresh = FOLDER_THRESHOLD;
     pCabParams->setID = 0xbeef;
+    pCabParams->iCab = 1;
     lstrcpyA(pCabParams->szCabPath, CURR_DIR);
     lstrcatA(pCabParams->szCabPath, "\\");
     lstrcpyA(pCabParams->szCab, name);
 }
 
-static void create_cab_file(const CHAR *name)
+static void create_cab_file(const CHAR *name, DWORD max_size, const CHAR *files)
 {
     CCAB cabParams;
+    LPCSTR ptr;
     HFCI hfci;
     ERF erf;
-    static CHAR four_txt[] = "four.txt",
-                five_txt[] = "five.txt";
     BOOL res;
 
-    set_cab_parameters(&cabParams, name);
+    set_cab_parameters(&cabParams, name, max_size);
 
     hfci = FCICreate(&erf, file_placed, mem_alloc, mem_free, fci_open,
                       fci_read, fci_write, fci_close, fci_seek, fci_delete,
@@ -416,8 +423,13 @@ static void create_cab_file(const CHAR *name)
 
     ok(hfci != NULL, "Failed to create an FCI context\n");
 
-    add_file(hfci, four_txt);
-    add_file(hfci, five_txt);
+    ptr = files;
+    while (*ptr)
+    {
+        res = add_file(hfci, ptr, tcompTYPE_MSZIP);
+        ok(res, "Failed to add file: %s\n", ptr);
+        ptr += lstrlen(ptr) + 1;
+    }
 
     res = FCIFlushCabinet(hfci, FALSE, get_next_cabinet, progress);
     ok(res, "Failed to flush the cabinet\n");
@@ -426,23 +438,9 @@ static void create_cab_file(const CHAR *name)
     ok(res, "Failed to destroy the cabinet\n");
 }
 
-static BOOL init_function_pointers(void)
-{
-    hCabinet = LoadLibraryA("cabinet.dll");
-    if (!hCabinet)
-        return FALSE;
-
-    pExtract = (void *)GetProcAddress(hCabinet, "Extract");
-    if (!pExtract)
-        return FALSE;
-
-    return TRUE;
-}
-
 static BOOL get_program_files_dir(LPSTR buf)
 {
     HKEY hkey;
-    CHAR temp[MAX_PATH];
     DWORD type = REG_EXPAND_SZ, size;
 
     if (RegOpenKey(HKEY_LOCAL_MACHINE,
@@ -450,49 +448,46 @@ static BOOL get_program_files_dir(LPSTR buf)
         return FALSE;
 
     size = MAX_PATH;
-    if (RegQueryValueEx(hkey, "ProgramFilesPath", 0, &type, (LPBYTE)temp, &size))
+    if (RegQueryValueEx(hkey, "ProgramFilesDir", 0, &type, (LPBYTE)buf, &size))
         return FALSE;
 
-    ExpandEnvironmentStrings(temp, buf, MAX_PATH);
-
     RegCloseKey(hkey);
     return TRUE;
 }
 
-static void create_file(const CHAR *name)
+static void create_file(const CHAR *name, DWORD size)
 {
     HANDLE file;
-    DWORD written;
+    DWORD written, left;
 
     file = CreateFileA(name, GENERIC_WRITE, 0, NULL, CREATE_ALWAYS, 0, NULL);
     ok(file != INVALID_HANDLE_VALUE, "Failure to open file %s\n", name);
     WriteFile(file, name, strlen(name), &written, NULL);
     WriteFile(file, "\n", strlen("\n"), &written, NULL);
+
+    left = size - lstrlen(name) - 1;
+
+    SetFilePointer(file, left, NULL, FILE_CURRENT);
+    SetEndOfFile(file);
+    
     CloseHandle(file);
 }
 
 static void create_test_files(void)
 {
-    int len;
-
-    GetCurrentDirectoryA(MAX_PATH, CURR_DIR);
-    len = lstrlenA(CURR_DIR);
-
-    if(len && (CURR_DIR[len-1] == '\\'))
-        CURR_DIR[len - 1] = 0;
-
-    get_program_files_dir(PROG_FILES_DIR);
-
     CreateDirectoryA("msitest", NULL);
-    create_file("msitest\\one.txt");
+    create_file("msitest\\one.txt", 100);
     CreateDirectoryA("msitest\\first", NULL);
-    create_file("msitest\\first\\two.txt");
+    create_file("msitest\\first\\two.txt", 100);
     CreateDirectoryA("msitest\\second", NULL);
-    create_file("msitest\\second\\three.txt");
+    create_file("msitest\\second\\three.txt", 100);
 
-    create_file("four.txt");
-    create_file("five.txt");
-    create_cab_file("msitest.cab");
+    create_file("four.txt", 100);
+    create_file("five.txt", 100);
+    create_cab_file("msitest.cab", MEDIA_SIZE, "four.txt\0five.txt\0");
+
+    create_file("msitest\\filename", 100);
+    create_file("msitest\\service.exe", 100);
 
     DeleteFileA("four.txt");
     DeleteFileA("five.txt");
@@ -519,6 +514,8 @@ static void delete_test_files(void)
     DeleteFileA("msitest\\second\\three.txt");
     DeleteFileA("msitest\\first\\two.txt");
     DeleteFileA("msitest\\one.txt");
+    DeleteFileA("msitest\\service.exe");
+    DeleteFileA("msitest\\filename");
     RemoveDirectoryA("msitest\\second");
     RemoveDirectoryA("msitest\\first");
     RemoveDirectoryA("msitest");
@@ -593,6 +590,21 @@ static void create_database(const CHAR *name, const msi_table *tables, int num_t
     MsiCloseHandle(db);
 }
 
+static void check_service_is_installed(void)
+{
+    SC_HANDLE scm, service;
+    BOOL res;
+
+    scm = OpenSCManager(NULL, NULL, SC_MANAGER_ALL_ACCESS);
+    ok(scm != NULL, "Failed to open the SC Manager\n");
+
+    service = OpenService(scm, "TestService", SC_MANAGER_ALL_ACCESS);
+    ok(service != NULL, "Failed to open TestService\n");
+
+    res = DeleteService(service);
+    ok(res, "Failed to delete TestService\n");
+}
+
 static void test_MsiInstallProduct(void)
 {
     UINT r;
@@ -601,22 +613,24 @@ static void test_MsiInstallProduct(void)
     HKEY hkey;
     DWORD num, size, type;
 
+    create_test_files();
+    create_database(msifile, tables, sizeof(tables) / sizeof(msi_table));
+
     r = MsiInstallProductA(msifile, NULL);
     ok(r == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %u\n", r);
 
-    todo_wine
-    {
-        ok(delete_pf("msitest\\cabout\\new\\five.txt", TRUE), "File not installed\n");
-        ok(delete_pf("msitest\\cabout\\new", FALSE), "File not installed\n");
-        ok(delete_pf("msitest\\cabout\\four.txt", TRUE), "File not installed\n");
-        ok(delete_pf("msitest\\cabout", FALSE), "File not installed\n");
-        ok(delete_pf("msitest\\changed\\three.txt", TRUE), "File not installed\n");
-        ok(delete_pf("msitest\\changed", FALSE), "File not installed\n");
-        ok(delete_pf("msitest\\first\\two.txt", TRUE), "File not installed\n");
-        ok(delete_pf("msitest\\first", FALSE), "File not installed\n");
-        ok(delete_pf("msitest\\one.txt", TRUE), "File not installed\n");
-        ok(delete_pf("msitest", FALSE), "File not installed\n");
-    }
+    ok(delete_pf("msitest\\cabout\\new\\five.txt", TRUE), "File not installed\n");
+    ok(delete_pf("msitest\\cabout\\new", FALSE), "File not installed\n");
+    ok(delete_pf("msitest\\cabout\\four.txt", TRUE), "File not installed\n");
+    ok(delete_pf("msitest\\cabout", FALSE), "File not installed\n");
+    ok(delete_pf("msitest\\changed\\three.txt", TRUE), "File not installed\n");
+    ok(delete_pf("msitest\\changed", FALSE), "File not installed\n");
+    ok(delete_pf("msitest\\first\\two.txt", TRUE), "File not installed\n");
+    ok(delete_pf("msitest\\first", FALSE), "File not installed\n");
+    ok(delete_pf("msitest\\one.txt", TRUE), "File not installed\n");
+    ok(delete_pf("msitest\\filename", TRUE), "File not installed\n");
+    ok(delete_pf("msitest\\service.exe", TRUE), "File not installed\n");
+    ok(delete_pf("msitest", FALSE), "File not installed\n");
 
     res = RegOpenKey(HKEY_LOCAL_MACHINE, "SOFTWARE\\Wine\\msitest", &hkey);
     ok(res == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %d\n", res);
@@ -630,10 +644,7 @@ static void test_MsiInstallProduct(void)
     size = MAX_PATH;
     type = REG_SZ;
     res = RegQueryValueExA(hkey, "blah", NULL, &type, (LPBYTE)path, &size);
-    todo_wine
-    {
-        ok(res == ERROR_FILE_NOT_FOUND, "Expected ERROR_FILE_NOT_FOUND, got %d\n", res);
-    }
+    ok(res == ERROR_FILE_NOT_FOUND, "Expected ERROR_FILE_NOT_FOUND, got %d\n", res);
 
     size = sizeof(num);
     type = REG_DWORD;
@@ -641,15 +652,28 @@ static void test_MsiInstallProduct(void)
     ok(res == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %d\n", res);
     ok(num == 314, "Expected 314, got %d\n", num);
 
+    size = MAX_PATH;
+    type = REG_SZ;
+    res = RegQueryValueExA(hkey, "OrderTestName", NULL, &type, (LPBYTE)path, &size);
+    ok(res == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %d\n", res);
+    ok(!lstrcmpA(path, "OrderTestValue"), "Expected imaname, got %s\n", path);
+
+    check_service_is_installed();
+
     RegDeleteKeyA(HKEY_LOCAL_MACHINE, "SOFTWARE\\Wine\\msitest");
+
+    delete_test_files();
 }
 
 static void test_MsiSetComponentState(void)
 {
+    INSTALLSTATE installed, action;
     MSIHANDLE package;
     char path[MAX_PATH];
     UINT r;
 
+    create_database(msifile, tables, sizeof(tables) / sizeof(msi_table));
+
     CoInitialize(NULL);
 
     lstrcpy(path, CURR_DIR);
@@ -668,11 +692,18 @@ static void test_MsiSetComponentState(void)
     r = MsiDoAction(package, "CostFinalize");
     ok(r == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %u\n", r);
 
+    r = MsiGetComponentState(package, "dangler", &installed, &action);
+    ok(r == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %u\n", r);
+    ok(installed == INSTALLSTATE_ABSENT, "Expected INSTALLSTATE_ABSENT, got %d\n", installed);
+    ok(action == INSTALLSTATE_UNKNOWN, "Expected INSTALLSTATE_UNKNOWN, got %d\n", action);
+
     r = MsiSetComponentState(package, "dangler", INSTALLSTATE_SOURCE);
     ok(r == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %u\n", r);
 
     MsiCloseHandle(package);
     CoUninitialize();
+
+    DeleteFileA(msifile);
 }
 
 static void test_packagecoltypes(void)
@@ -682,6 +713,8 @@ static void test_packagecoltypes(void)
     LPCSTR query;
     UINT r, count;
 
+    create_database(msifile, tables, sizeof(tables) / sizeof(msi_table));
+
     CoInitialize(NULL);
 
     lstrcpy(path, CURR_DIR);
@@ -711,15 +744,12 @@ static void test_packagecoltypes(void)
     count = MsiRecordGetFieldCount( rec );
     ok(r == ERROR_SUCCESS, "MsiViewGetColumnInfo failed\n");
     ok(count == 6, "Expected 6, got %d\n", count);
+    ok(check_record(rec, 1, "i2"), "wrong column label\n");
+    ok(check_record(rec, 2, "i4"), "wrong column label\n");
+    ok(check_record(rec, 3, "L64"), "wrong column label\n");
     ok(check_record(rec, 4, "S255"), "wrong column label\n");
     ok(check_record(rec, 5, "S32"), "wrong column label\n");
     ok(check_record(rec, 6, "S72"), "wrong column label\n");
-    todo_wine
-    {
-        ok(check_record(rec, 1, "i2"), "wrong column label\n");
-        ok(check_record(rec, 2, "i4"), "wrong column label\n");
-        ok(check_record(rec, 3, "L64"), "wrong column label\n");
-    }
 
     MsiCloseHandle(rec);
     MsiCloseHandle(view);
@@ -727,17 +757,135 @@ static void test_packagecoltypes(void)
     DeleteFile(msifile);
 }
 
+static void create_cc_test_files(void)
+{
+    CCAB cabParams;
+    HFCI hfci;
+    ERF erf;
+    BOOL res;
+
+    create_file("maximus", 500);
+    create_file("augustus", 50000);
+
+    set_cab_parameters(&cabParams, "test1.cab", 200);
+
+    hfci = FCICreate(&erf, file_placed, mem_alloc, mem_free, fci_open,
+                      fci_read, fci_write, fci_close, fci_seek, fci_delete,
+                      get_temp_file, &cabParams, (void*)"test%d.cab");
+    ok(hfci != NULL, "Failed to create an FCI context\n");
+
+    /* spews out hundreds of cab files.  re-enable when cabinet.dll is fixed */
+#if 0
+    res = add_file(hfci, "maximus", tcompTYPE_MSZIP);
+    ok(res, "Failed to add file maximus\n");
+
+    res = add_file(hfci, "augustus", tcompTYPE_MSZIP);
+    todo_wine
+    {
+        ok(res, "Failed to add file augustus\n");
+    }
+#endif
+
+    res = FCIFlushCabinet(hfci, FALSE, get_next_cabinet, progress);
+    ok(res, "Failed to flush the cabinet\n");
+
+    res = FCIDestroy(hfci);
+    ok(res, "Failed to destroy the cabinet\n");
+
+    DeleteFile("maximus");
+    DeleteFile("augustus");
+}
+
+static void test_continuouscabs(void)
+{
+    UINT r;
+
+    create_cc_test_files();
+    create_database(msifile, cc_tables, sizeof(cc_tables) / sizeof(msi_table));
+
+    MsiSetInternalUI(INSTALLUILEVEL_NONE, NULL);
+
+    r = MsiInstallProductA(msifile, NULL);
+    todo_wine
+    {
+        ok(r == ERROR_SUCCESS, "Expected ERROR_SUCCESS, got %u\n", r);
+    }
+
+    todo_wine
+    {
+        ok(delete_pf("msitest\\maximus", TRUE), "File not installed\n");
+        ok(delete_pf("msitest\\augustus", TRUE), "File not installed\n");
+    }
+    ok(delete_pf("msitest", FALSE), "File not installed\n");
+
+    DeleteFile("test1.cab");
+    DeleteFile("test2.cab");
+    DeleteFile(msifile);
+}
+
+static void test_caborder(void)
+{
+    UINT r;
+
+    create_file("imperator", 100);
+    create_file("maximus", 500);
+    create_file("augustus", 50000);
+
+    create_database(msifile, cc_tables, sizeof(cc_tables) / sizeof(msi_table));
+
+    MsiSetInternalUI(INSTALLUILEVEL_NONE, NULL);
+
+    create_cab_file("test1.cab", MEDIA_SIZE, "maximus\0");
+    create_cab_file("test2.cab", MEDIA_SIZE, "augustus\0");
+
+    r = MsiInstallProductA(msifile, NULL);
+    ok(r == ERROR_INSTALL_FAILURE, "Expected ERROR_INSTALL_FAILURE, got %u\n", r);
+    ok(!delete_pf("msitest\\augustus", TRUE), "File is installed\n");
+    todo_wine
+    {
+    	ok(!delete_pf("msitest\\maximus", TRUE), "File is installed\n");
+    	ok(!delete_pf("msitest", FALSE), "File is installed\n");
+    }
+
+    DeleteFile("test1.cab");
+    DeleteFile("test2.cab");
+
+    create_cab_file("test1.cab", MEDIA_SIZE, "imperator\0");
+    create_cab_file("test2.cab", MEDIA_SIZE, "maximus\0augustus\0");
+
+    r = MsiInstallProductA(msifile, NULL);
+    ok(r == ERROR_INSTALL_FAILURE, "Expected ERROR_INSTALL_FAILURE, got %u\n", r);
+    ok(!delete_pf("msitest\\maximus", TRUE), "File is installed\n");
+    ok(!delete_pf("msitest\\augustus", TRUE), "File is installed\n");
+    todo_wine
+    {
+    	ok(!delete_pf("msitest", FALSE), "File is installed\n");
+    }
+
+    DeleteFile("test1.cab");
+    DeleteFile("test2.cab");
+
+    DeleteFile("imperator");
+    DeleteFile("maximus");
+    DeleteFile("augustus");
+    DeleteFile(msifile);
+}
+
 START_TEST(install)
 {
-    if (!init_function_pointers())
-        return;
+    DWORD len;
 
-    create_test_files();
-    create_database(msifile, tables, sizeof(tables) / sizeof(msi_table));
+    get_program_files_dir(PROG_FILES_DIR);
+
+    GetCurrentDirectoryA(MAX_PATH, CURR_DIR);
+    len = lstrlenA(CURR_DIR);
+
+    if(len && (CURR_DIR[len-1] == '\\'))
+        CURR_DIR[len - 1] = 0;
 
     test_MsiInstallProduct();
     test_MsiSetComponentState();
     test_packagecoltypes();
-
-    delete_test_files();
+    test_continuouscabs();
+    test_caborder();
 }
