@@ -272,7 +272,7 @@ _get_typeinfo_for_iid(REFIID riid, ITypeInfo**ti) {
     LONG	tlfnlen;
     ITypeLib	*tl;
 
-    sprintf( interfacekey, "Interface\\{%08lx-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x}\\Typelib",
+    sprintf( interfacekey, "Interface\\{%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x}\\Typelib",
 	riid->Data1, riid->Data2, riid->Data3,
 	riid->Data4[0], riid->Data4[1], riid->Data4[2], riid->Data4[3],
 	riid->Data4[4], riid->Data4[5], riid->Data4[6], riid->Data4[7]
@@ -315,7 +315,7 @@ _get_typeinfo_for_iid(REFIID riid, ITypeInfo**ti) {
 	ITypeLib_Release(tl);
 	return hres;
     }
-    /* FIXME: do this?  ITypeLib_Release(tl); */
+    ITypeLib_Release(tl);
     return hres;
 }
 
@@ -417,6 +417,7 @@ TMProxyImpl_Release(LPRPCPROXYBUFFER iface)
         if (This->chanbuf) IRpcChannelBuffer_Release(This->chanbuf);
         VirtualFree(This->asmstubs, 0, MEM_RELEASE);
         HeapFree(GetProcessHeap(), 0, This->lpvtbl);
+        ITypeInfo_Release(This->tinfo);
         CoTaskMemFree(This);
     }
     return refCount;
@@ -539,7 +540,7 @@ serialize_param(
     case VT_UI8:
     case VT_CY:
 	hres = S_OK;
-	if (debugout) TRACE_(olerelay)("%x%x",arg[0],arg[1]);
+	if (debugout) TRACE_(olerelay)("%x%x\n",arg[0],arg[1]);
 	if (writeit)
 	    hres = xbuf_add(buf,(LPBYTE)arg,8);
 	return hres;
@@ -551,27 +552,27 @@ serialize_param(
     case VT_R4:
     case VT_UI4:
 	hres = S_OK;
-	if (debugout) TRACE_(olerelay)("%x",*arg);
+	if (debugout) TRACE_(olerelay)("%x\n",*arg);
 	if (writeit)
 	    hres = xbuf_add(buf,(LPBYTE)arg,sizeof(DWORD));
 	return hres;
     case VT_I2:
     case VT_UI2:
 	hres = S_OK;
-	if (debugout) TRACE_(olerelay)("%04x",*arg & 0xffff);
+	if (debugout) TRACE_(olerelay)("%04x\n",*arg & 0xffff);
 	if (writeit)
 	    hres = xbuf_add(buf,(LPBYTE)arg,sizeof(DWORD));
 	return hres;
     case VT_I1:
     case VT_UI1:
 	hres = S_OK;
-	if (debugout) TRACE_(olerelay)("%02x",*arg & 0xff);
+	if (debugout) TRACE_(olerelay)("%02x\n",*arg & 0xff);
 	if (writeit)
 	    hres = xbuf_add(buf,(LPBYTE)arg,sizeof(DWORD));
 	return hres;
     case VT_I4|VT_BYREF:
 	hres = S_OK;
-	if (debugout) TRACE_(olerelay)("&0x%x",*arg);
+	if (debugout) TRACE_(olerelay)("&0x%x\n",*arg);
 	if (writeit)
 	    hres = xbuf_add(buf,(LPBYTE)(DWORD*)*arg,sizeof(DWORD));
 	/* do not dealloc at this time */
@@ -675,6 +676,7 @@ serialize_param(
 		derefhere=FALSE;
 		break;
 	    }
+	    ITypeInfo_ReleaseTypeAttr(tinfo, tattr);
 	    ITypeInfo_Release(tinfo2);
 	}
 
@@ -741,16 +743,6 @@ serialize_param(
 		    ERR("Could not get vardesc of %d\n",i);
 		    return hres;
 		}
-		/* Need them for hack below */
-		/*
-		memset(names,0,sizeof(names));
-		hres = ITypeInfo_GetNames(tinfo2,vdesc->memid,names,sizeof(names)/sizeof(names[0]),&nrofnames);
-		if (nrofnames > sizeof(names)/sizeof(names[0])) {
-		    ERR("Need more names!\n");
-		}
-		if (!hres && debugout)
-		    TRACE_(olerelay)("%s=",relaystr(names[0]));
-		*/
 		elem2 = &vdesc->elemdescVar;
 		tdesc2 = &elem2->tdesc;
 		hres = serialize_param(
@@ -772,18 +764,20 @@ serialize_param(
 	    break;
 	}
 	case TKIND_ALIAS:
-	    return serialize_param(tinfo2,writeit,debugout,dealloc,&tattr->tdescAlias,arg,buf);
+	    hres = serialize_param(tinfo2,writeit,debugout,dealloc,&tattr->tdescAlias,arg,buf);
+	    break;
 	case TKIND_ENUM:
 	    hres = S_OK;
 	    if (debugout) TRACE_(olerelay)("%x",*arg);
 	    if (writeit)
 	        hres = xbuf_add(buf,(LPBYTE)arg,sizeof(DWORD));
-	    return hres;
+	    break;
 	default:
 	    FIXME("Unhandled typekind %d\n",tattr->typekind);
 	    hres = E_FAIL;
 	    break;
 	}
+	ITypeInfo_ReleaseTypeAttr(tinfo2, tattr);
 	ITypeInfo_Release(tinfo2);
 	return hres;
     }
@@ -841,10 +835,10 @@ deserialize_param(
     while (1) {
 	switch (tdesc->vt) {
 	case VT_EMPTY:
-	    if (debugout) TRACE_(olerelay)("<empty>");
+	    if (debugout) TRACE_(olerelay)("<empty>\n");
 	    return S_OK;
 	case VT_NULL:
-	    if (debugout) TRACE_(olerelay)("<null>");
+	    if (debugout) TRACE_(olerelay)("<null>\n");
 	    return S_OK;
 	case VT_VARIANT: {
 	    VARIANT	*vt = (VARIANT*)arg;
@@ -1011,6 +1005,7 @@ deserialize_param(
 		    derefhere=FALSE;
 		    break;
 		}
+		ITypeInfo_ReleaseTypeAttr(tinfo2, tattr);
 		ITypeInfo_Release(tinfo2);
 	    }
 	    /* read it in all cases, we need to know if we have 
@@ -1090,6 +1085,8 @@ deserialize_param(
 			hres = ITypeInfo2_GetVarDesc(tinfo2, i, &vdesc);
 			if (hres) {
 			    ERR("Could not get vardesc of %d\n",i);
+			    ITypeInfo_ReleaseTypeAttr(tinfo2, tattr);
+			    ITypeInfo_Release(tinfo2);
 			    return hres;
 			}
 			hres = deserialize_param(
@@ -1108,19 +1105,21 @@ deserialize_param(
 		    break;
 		}
 		case TKIND_ALIAS:
-		    return deserialize_param(tinfo2,readit,debugout,alloc,&tattr->tdescAlias,arg,buf);
+		    hres = deserialize_param(tinfo2,readit,debugout,alloc,&tattr->tdescAlias,arg,buf);
+		    break;
 		case TKIND_ENUM:
 		    if (readit) {
 		        hres = xbuf_get(buf,(LPBYTE)arg,sizeof(DWORD));
 		        if (hres) ERR("Failed to read enum (4 byte)\n");
 		    }
 		    if (debugout) TRACE_(olerelay)("%x",*arg);
-		    return hres;
+		    break;
 		default:
 		    ERR("Unhandled typekind %d\n",tattr->typekind);
 		    hres = E_FAIL;
 		    break;
 		}
+		ITypeInfo_ReleaseTypeAttr(tinfo2, tattr);
 	    }
 	    if (hres)
 		ERR("failed to stuballoc in TKIND_RECORD.\n");
@@ -1175,9 +1174,6 @@ _get_funcdesc(
     if (fname) *fname = NULL;
     if (iname) *iname = NULL;
 
-    *tactual = tinfo;
-    ITypeInfo_AddRef(*tactual);
-
     while (1) {
 	hres = ITypeInfoImpl_GetInternalFuncDesc(tinfo, i, fdesc);
 
@@ -1205,8 +1201,12 @@ _get_funcdesc(
 		}
 		hres = _get_funcdesc(tinfo2,iMethod,tactual,fdesc,iname,fname);
 		ITypeInfo_Release(tinfo2);
-		if (!hres) return S_OK;
+		if (!hres) {
+		    ITypeInfo_ReleaseTypeAttr(tinfo, attr);
+		    return S_OK;
+                }
 	    }
+	    ITypeInfo_ReleaseTypeAttr(tinfo, attr);
 	    return hres;
 	}
 	if (((*fdesc)->oVft/4) == iMethod) {
@@ -1214,6 +1214,8 @@ _get_funcdesc(
 		ITypeInfo_GetDocumentation(tinfo,(*fdesc)->memid,fname,NULL,NULL,NULL);
 	    if (iname)
 		ITypeInfo_GetDocumentation(tinfo,-1,iname,NULL,NULL,NULL);
+	    *tactual = tinfo;
+	    ITypeInfo_AddRef(*tactual);
 	    return S_OK;
 	}
 	i++;
@@ -1382,6 +1384,8 @@ xCall(LPVOID retptr, int method, TMProxyImpl *tpinfo /*, args */)
     hres = remoteresult;
 
 exit:
+    for (i = 0; i < nrofnames; i++)
+        SysFreeString(names[i]);
     HeapFree(GetProcessHeap(),0,buf.base);
     IRpcChannelBuffer_Release(chanbuf);
     ITypeInfo_Release(tinfo);
@@ -1717,12 +1721,12 @@ TMStubImpl_Invoke(
     const FUNCDESC *fdesc;
     TMStubImpl *This = (TMStubImpl *)iface;
     HRESULT	hres;
-    DWORD	*args, res, *xargs, nrofargs;
+    DWORD	*args = NULL, res, *xargs, nrofargs;
     marshal_state	buf;
     UINT	nrofnames;
     BSTR	names[10];
     BSTR	iname = NULL;
-    ITypeInfo 	*tinfo;
+    ITypeInfo 	*tinfo = NULL;
 
     TRACE("...\n");
 
@@ -1761,8 +1765,9 @@ TMStubImpl_Invoke(
     if (iname && !lstrcmpW(iname, IDispatchW))
     {
         ERR("IDispatch cannot be marshaled by the typelib marshaler\n");
-        ITypeInfo_Release(tinfo);
-        return E_UNEXPECTED;
+        hres = E_UNEXPECTED;
+        SysFreeString (iname);
+        goto exit;
     }
 
     if (iname) SysFreeString (iname);
@@ -1779,7 +1784,11 @@ TMStubImpl_Invoke(
     for (i=0;i<fdesc->cParams;i++)
 	nrofargs += _argsize(fdesc->lprgelemdescParam[i].tdesc.vt);
     args = HeapAlloc(GetProcessHeap(),0,(nrofargs+1)*sizeof(DWORD));
-    if (!args) return E_OUTOFMEMORY;
+    if (!args)
+    {
+        hres = E_OUTOFMEMORY;
+        goto exit;
+    }
 
     /* Allocate all stuff used by call. */
     xargs = args+1;
@@ -1825,7 +1834,7 @@ TMStubImpl_Invoke(
     __ENDTRY
 
     if (hres != S_OK)
-        return hres;
+        goto exit;
 
     buf.curoff = 0;
 
@@ -1849,11 +1858,9 @@ TMStubImpl_Invoke(
     }
 
     hres = xbuf_add (&buf, (LPBYTE)&res, sizeof(DWORD));
-    if (hres != S_OK)
-	return hres;
 
-    ITypeInfo_Release(tinfo);
-    HeapFree(GetProcessHeap(), 0, args);
+    if (hres != S_OK)
+        goto exit;
 
     xmsg->cbBuffer	= buf.curoff;
     hres = IRpcChannelBuffer_GetBuffer(rpcchanbuf, xmsg, &This->iid);
@@ -1863,6 +1870,13 @@ TMStubImpl_Invoke(
     if (hres == S_OK)
         memcpy(xmsg->Buffer, buf.base, buf.curoff);
 
+exit:
+    for (i = 0; i < nrofnames; i++)
+        SysFreeString(names[i]);
+
+    ITypeInfo_Release(tinfo);
+    HeapFree(GetProcessHeap(), 0, args);
+
     HeapFree(GetProcessHeap(), 0, buf.base);
 
     TRACE("returning\n");
