@@ -50,6 +50,8 @@ WINE_DEFAULT_DEBUG_CHANNEL(rpc);
 #define ROUND_UP_AMOUNT(value, alignment) \
     (((alignment) - (((value) % (alignment)))) % (alignment))
 
+static RPC_STATUS I_RpcReAllocateBuffer(PRPC_MESSAGE pMsg);
+
 static DWORD RPCRT4_GetHeaderSize(RpcPktHdr *Header)
 {
   static const DWORD header_sizes[] = {
@@ -475,7 +477,8 @@ RPC_STATUS RPCRT4_Receive(RpcConnection *Connection, RpcPktHdr **Header,
   unsigned short first_flag;
   unsigned long data_length;
   unsigned long buffer_length;
-  unsigned char *buffer_ptr;
+  unsigned long auth_length;
+  unsigned char *auth_data = NULL;
   RpcPktCommonHdr common_hdr;
 
   *Header = NULL;
@@ -525,7 +528,7 @@ RPC_STATUS RPCRT4_Receive(RpcConnection *Connection, RpcPktHdr **Header,
     pMsg->BufferLength = (*Header)->request.alloc_hint;
     break;
   default:
-    pMsg->BufferLength = common_hdr.frag_len - hdr_length;
+    pMsg->BufferLength = common_hdr.frag_len - hdr_length - RPC_AUTH_VERIFIER_LEN(&common_hdr);
   }
 
   TRACE("buffer length = %u\n", pMsg->BufferLength);
@@ -534,36 +537,77 @@ RPC_STATUS RPCRT4_Receive(RpcConnection *Connection, RpcPktHdr **Header,
   if (status != RPC_S_OK) goto fail;
 
   first_flag = RPC_FLG_FIRST;
+  auth_length = common_hdr.auth_len;
+  if (auth_length) {
+    auth_data = HeapAlloc(GetProcessHeap(), 0, RPC_AUTH_VERIFIER_LEN(&common_hdr));
+    if (!auth_data) {
+      status = RPC_S_PROTOCOL_ERROR;
+      goto fail;
+    }
+  }
   buffer_length = 0;
-  buffer_ptr = pMsg->Buffer;
-  while (buffer_length < pMsg->BufferLength)
+  while (TRUE)
   {
-    data_length = (*Header)->common.frag_len - hdr_length;
-    if (((*Header)->common.flags & RPC_FLG_FIRST) != first_flag ||
-        data_length + buffer_length > pMsg->BufferLength) {
-      TRACE("invalid packet flags or buffer length\n");
+    unsigned int header_auth_len = RPC_AUTH_VERIFIER_LEN(&(*Header)->common);
+
+    /* verify header fields */
+
+    if (((*Header)->common.frag_len < hdr_length) ||
+        ((*Header)->common.frag_len - hdr_length < header_auth_len)) {
+      WARN("frag_len %d too small for hdr_length %ld and auth_len %d\n",
+        common_hdr.frag_len, hdr_length, common_hdr.auth_len);
       status = RPC_S_PROTOCOL_ERROR;
       goto fail;
     }
 
+    if ((*Header)->common.auth_len != auth_length) {
+      WARN("auth_len header field changed from %ld to %d\n",
+        auth_length, (*Header)->common.auth_len);
+      status = RPC_S_PROTOCOL_ERROR;
+      goto fail;
+    }
+
+    if (((*Header)->common.flags & RPC_FLG_FIRST) != first_flag) {
+      TRACE("invalid packet flags\n");
+      status = RPC_S_PROTOCOL_ERROR;
+      goto fail;
+    }
+
+    data_length = (*Header)->common.frag_len - hdr_length - header_auth_len;
+    if (data_length + buffer_length > pMsg->BufferLength) {
+      TRACE("allocation hint exceeded, new buffer length = %ld\n",
+        data_length + buffer_length);
+      pMsg->BufferLength = data_length + buffer_length;
+      status = I_RpcReAllocateBuffer(pMsg);
+      if (status != RPC_S_OK) goto fail;
+    }
+
     if (data_length == 0) dwRead = 0; else
-    dwRead = rpcrt4_conn_read(Connection, buffer_ptr, data_length);
+    dwRead = rpcrt4_conn_read(Connection,
+        (unsigned char *)pMsg->Buffer + buffer_length, data_length);
     if (dwRead != data_length) {
       WARN("bad data length, %ld/%ld\n", dwRead, data_length);
       status = RPC_S_PROTOCOL_ERROR;
       goto fail;
     }
 
-    /* when there is no more data left, it should be the last packet */
-    if (buffer_length == pMsg->BufferLength &&
-        ((*Header)->common.flags & RPC_FLG_LAST) == 0) {
-      WARN("no more data left, but not last packet\n");
-      status = RPC_S_PROTOCOL_ERROR;
-      goto fail;
+    if (header_auth_len) {
+      /* FIXME: we should accumulate authentication data for the bind,
+       * bind_ack, alter_context and alter_context_response if necessary.
+       * however, the details of how this is done is very sketchy in the
+       * DCE/RPC spec. for all other packet types that have authentication
+       * verifier data then it is just duplicated in all the fragments */
+      dwRead = rpcrt4_conn_read(Connection, auth_data, header_auth_len);
+      if (dwRead != header_auth_len) {
+        WARN("bad authentication data length, %ld/%d\n", dwRead,
+          header_auth_len);
+        status = RPC_S_PROTOCOL_ERROR;
+        goto fail;
+      }
     }
 
     buffer_length += data_length;
-    if (buffer_length < pMsg->BufferLength) {
+    if (!((*Header)->common.flags & RPC_FLG_LAST)) {
       TRACE("next header\n");
 
       /* read the header of next packet */
@@ -574,19 +618,19 @@ RPC_STATUS RPCRT4_Receive(RpcConnection *Connection, RpcPktHdr **Header,
         goto fail;
       }
 
-      buffer_ptr += data_length;
       first_flag = 0;
+    } else {
+      break;
     }
   }
+  pMsg->BufferLength = buffer_length;
 
   /* respond to authorization request */
-  if (common_hdr.ptype == PKT_BIND_ACK && common_hdr.auth_len > 8)
+  if (common_hdr.ptype == PKT_BIND_ACK && auth_length > sizeof(RpcAuthVerifier))
   {
-    unsigned int offset;
-
-    offset = common_hdr.frag_len - hdr_length - common_hdr.auth_len;
-    status = RPCRT_AuthorizeConnection(Connection, (LPBYTE)pMsg->Buffer + offset,
-                                       common_hdr.auth_len);
+    status = RPCRT_AuthorizeConnection(Connection,
+                                       auth_data + sizeof(RpcAuthVerifier),
+                                       auth_length);
     if (status)
         goto fail;
   }
@@ -595,10 +639,11 @@ RPC_STATUS RPCRT4_Receive(RpcConnection *Connection, RpcPktHdr **Header,
   status = RPC_S_OK;
 
 fail:
-  if (status != RPC_S_OK && *Header) {
+  if (status != RPC_S_OK) {
     RPCRT4_FreeHeader(*Header);
     *Header = NULL;
   }
+  HeapFree(GetProcessHeap(), 0, auth_data);
   return status;
 }
 
@@ -616,6 +661,18 @@ RPC_STATUS WINAPI I_RpcGetBuffer(PRPC_MESSAGE pMsg)
   return pMsg->Buffer ? S_OK : E_OUTOFMEMORY;
 }
 
+/***********************************************************************
+ *           I_RpcReAllocateBuffer (internal)
+ */
+static RPC_STATUS I_RpcReAllocateBuffer(PRPC_MESSAGE pMsg)
+{
+  TRACE("(%p): BufferLength=%d\n", pMsg, pMsg->BufferLength);
+  pMsg->Buffer = HeapReAlloc(GetProcessHeap(), 0, pMsg->Buffer, pMsg->BufferLength);
+
+  TRACE("Buffer=%p\n", pMsg->Buffer);
+  return pMsg->Buffer ? RPC_S_OK : RPC_S_OUT_OF_RESOURCES;
+}
+
 /***********************************************************************
  *           I_RpcFreeBuffer [RPCRT4.@]
  */
@@ -765,9 +822,7 @@ RPC_STATUS WINAPI I_RpcReceive(PRPC_MESSAGE pMsg)
   status = RPC_S_OK;
 
 fail:
-  if (hdr) {
-    RPCRT4_FreeHeader(hdr);
-  }
+  RPCRT4_FreeHeader(hdr);
   RPCRT4_CloseBinding(bind, conn);
   return status;
 }
