@@ -66,7 +66,8 @@ typedef struct _RpcObjTypeMap
 
 static RpcObjTypeMap *RpcObjTypeMaps;
 
-static RpcServerProtseq* protseqs;
+/* list of type RpcServerProtseq */
+static struct list protseqs = LIST_INIT(protseqs);
 static RpcServerInterface* ifs;
 
 static CRITICAL_SECTION server_cs;
@@ -93,12 +94,6 @@ static BOOL std_listen;
 static LONG manual_listen_count;
 /* total listeners including auto listeners */
 static LONG listen_count;
-/* set on change of configuration (e.g. listening on new protseq) */
-static HANDLE mgr_event;
-/* mutex for ensuring only one thread can change state at a time */
-static HANDLE mgr_mutex;
-/* set when server thread has finished opening connections */
-static HANDLE server_ready_event;
 
 static UUID uuid_nil;
 
@@ -337,7 +332,7 @@ static DWORD CALLBACK RPCRT4_io_thread(LPVOID the_arg)
   return 0;
 }
 
-static void RPCRT4_new_client(RpcConnection* conn)
+void RPCRT4_new_client(RpcConnection* conn)
 {
   HANDLE thread = CreateThread(NULL, 0, RPCRT4_io_thread, conn, 0, NULL);
   if (!thread) {
@@ -355,130 +350,96 @@ static void RPCRT4_new_client(RpcConnection* conn)
 
 static DWORD CALLBACK RPCRT4_server_thread(LPVOID the_arg)
 {
-  HANDLE m_event = mgr_event, b_handle;
-  HANDLE *objs = NULL;
-  DWORD count, res;
-  RpcServerProtseq* cps;
+  int res;
+  unsigned int count;
+  void *objs = NULL;
+  RpcServerProtseq* cps = the_arg;
   RpcConnection* conn;
-  RpcConnection* cconn;
   BOOL set_ready_event = FALSE;
 
   TRACE("(the_arg == ^%p)\n", the_arg);
 
   for (;;) {
-    EnterCriticalSection(&server_cs);
-    /* open and count connections */
-    count = 1;
-    cps = protseqs;
-    while (cps) {
-      conn = cps->conn;
-      while (conn) {
-        RPCRT4_OpenConnection(conn);
-        if (rpcrt4_conn_get_wait_object(conn))
-          count++;
-        conn = conn->Next;
-      }
-      cps = cps->Next;
-    }
-    /* make array of connections */
-    if (objs)
-      objs = HeapReAlloc(GetProcessHeap(), 0, objs, count*sizeof(HANDLE));
-    else
-      objs = HeapAlloc(GetProcessHeap(), 0, count*sizeof(HANDLE));
-
-    objs[0] = m_event;
-    count = 1;
-    cps = protseqs;
-    while (cps) {
-      conn = cps->conn;
-      while (conn) {
-        if ((objs[count] = rpcrt4_conn_get_wait_object(conn)))
-          count++;
-        conn = conn->Next;
-      }
-      cps = cps->Next;
-    }
-    LeaveCriticalSection(&server_cs);
+    objs = cps->ops->get_wait_array(cps, objs, &count);
 
     if (set_ready_event)
     {
         /* signal to function that changed state that we are now sync'ed */
-        SetEvent(server_ready_event);
+        SetEvent(cps->server_ready_event);
         set_ready_event = FALSE;
     }
 
     /* start waiting */
-    res = WaitForMultipleObjects(count, objs, FALSE, INFINITE);
-    if (res == WAIT_OBJECT_0) {
+    res = cps->ops->wait_for_new_connection(cps, count, objs);
+    if (res == -1)
+      break;
+    else if (res == 0)
+    {
       if (!std_listen)
       {
-        SetEvent(server_ready_event);
+        SetEvent(cps->server_ready_event);
         break;
       }
       set_ready_event = TRUE;
     }
-    else if (res == WAIT_FAILED) {
-      ERR("wait failed\n");
-    }
-    else {
-      b_handle = objs[res - WAIT_OBJECT_0];
-      /* find which connection got a RPC */
-      EnterCriticalSection(&server_cs);
-      conn = NULL;
-      cps = protseqs;
-      while (cps) {
-        conn = cps->conn;
-        while (conn) {
-          if (b_handle == rpcrt4_conn_get_wait_object(conn)) break;
-          conn = conn->Next;
-        }
-        if (conn) break;
-        cps = cps->Next;
-      }
-      cconn = NULL;
-      if (conn)
-        RPCRT4_SpawnConnection(&cconn, conn);
-      else
-        ERR("failed to locate connection for handle %p\n", b_handle);
-      LeaveCriticalSection(&server_cs);
-      if (cconn) RPCRT4_new_client(cconn);
-    }
   }
-  HeapFree(GetProcessHeap(), 0, objs);
-  EnterCriticalSection(&server_cs);
+  cps->ops->free_wait_array(cps, objs);
+  EnterCriticalSection(&cps->cs);
   /* close connections */
-  cps = protseqs;
-  while (cps) {
-    conn = cps->conn;
-    while (conn) {
-      RPCRT4_CloseConnection(conn);
-      conn = conn->Next;
-    }
-    cps = cps->Next;
+  conn = cps->conn;
+  while (conn) {
+    RPCRT4_CloseConnection(conn);
+    conn = conn->Next;
   }
-  LeaveCriticalSection(&server_cs);
+  LeaveCriticalSection(&cps->cs);
   return 0;
 }
 
 /* tells the server thread that the state has changed and waits for it to
  * make the changes */
-static void RPCRT4_sync_with_server_thread(void)
+static void RPCRT4_sync_with_server_thread(RpcServerProtseq *ps)
 {
   /* make sure we are the only thread sync'ing the server state, otherwise
    * there is a race with the server thread setting an older state and setting
    * the server_ready_event when the new state hasn't yet been applied */
-  WaitForSingleObject(mgr_mutex, INFINITE);
+  WaitForSingleObject(ps->mgr_mutex, INFINITE);
+
+  ps->ops->signal_state_changed(ps);
 
-  SetEvent(mgr_event);
   /* wait for server thread to make the requested changes before returning */
-  WaitForSingleObject(server_ready_event, INFINITE);
+  WaitForSingleObject(ps->server_ready_event, INFINITE);
 
-  ReleaseMutex(mgr_mutex);
+  ReleaseMutex(ps->mgr_mutex);
+}
+
+static RPC_STATUS RPCRT4_start_listen_protseq(RpcServerProtseq *ps, BOOL auto_listen)
+{
+  RPC_STATUS status = RPC_S_OK;
+  HANDLE server_thread;
+
+  EnterCriticalSection(&listen_cs);
+  if (ps->is_listening) goto done;
+
+  if (!ps->mgr_mutex) ps->mgr_mutex = CreateMutexW(NULL, FALSE, NULL);
+  if (!ps->server_ready_event) ps->server_ready_event = CreateEventW(NULL, FALSE, FALSE, NULL);
+  server_thread = CreateThread(NULL, 0, RPCRT4_server_thread, ps, 0, NULL);
+  if (!server_thread)
+  {
+    status = RPC_S_OUT_OF_RESOURCES;
+    goto done;
+  }
+  ps->is_listening = TRUE;
+  CloseHandle(server_thread);
+
+done:
+  LeaveCriticalSection(&listen_cs);
+  return status;
 }
 
 static RPC_STATUS RPCRT4_start_listen(BOOL auto_listen)
 {
   RPC_STATUS status = RPC_S_ALREADY_LISTENING;
+  RpcServerProtseq *cps;
 
   TRACE("\n");
 
@@ -486,19 +447,27 @@ static RPC_STATUS RPCRT4_start_listen(BOOL auto_listen)
   if (auto_listen || (manual_listen_count++ == 0))
   {
     status = RPC_S_OK;
-    if (++listen_count == 1) {
-      HANDLE server_thread;
-      /* first listener creates server thread */
-      if (!mgr_mutex) mgr_mutex = CreateMutexW(NULL, FALSE, NULL);
-      if (!mgr_event) mgr_event = CreateEventW(NULL, FALSE, FALSE, NULL);
-      if (!server_ready_event) server_ready_event = CreateEventW(NULL, FALSE, FALSE, NULL);
+    if (++listen_count == 1)
       std_listen = TRUE;
-      server_thread = CreateThread(NULL, 0, RPCRT4_server_thread, NULL, 0, NULL);
-      CloseHandle(server_thread);
-    }
   }
   LeaveCriticalSection(&listen_cs);
 
+  if (std_listen)
+  {
+    EnterCriticalSection(&server_cs);
+    LIST_FOR_EACH_ENTRY(cps, &protseqs, RpcServerProtseq, entry)
+    {
+      status = RPCRT4_start_listen_protseq(cps, TRUE);
+      if (status != RPC_S_OK)
+        break;
+      
+      /* make sure server is actually listening on the interface before
+       * returning */
+      RPCRT4_sync_with_server_thread(cps);
+    }
+    LeaveCriticalSection(&server_cs);
+  }
+
   return status;
 }
 
@@ -508,9 +477,14 @@ static void RPCRT4_stop_listen(BOOL auto_listen)
   if (auto_listen || (--manual_listen_count == 0))
   {
     if (listen_count != 0 && --listen_count == 0) {
+      RpcServerProtseq *cps;
+
       std_listen = FALSE;
       LeaveCriticalSection(&listen_cs);
-      RPCRT4_sync_with_server_thread();
+
+      LIST_FOR_EACH_ENTRY(cps, &protseqs, RpcServerProtseq, entry)
+        RPCRT4_sync_with_server_thread(cps);
+
       return;
     }
     assert(listen_count >= 0);
@@ -520,17 +494,25 @@ static void RPCRT4_stop_listen(BOOL auto_listen)
 
 static RPC_STATUS RPCRT4_use_protseq(RpcServerProtseq* ps)
 {
-  RPCRT4_CreateConnection(&ps->conn, TRUE, ps->Protseq, NULL, ps->Endpoint,
-                          NULL, NULL, NULL);
+  RPC_STATUS status;
+
+  status = RPCRT4_CreateConnection(&ps->conn, TRUE, ps->Protseq, NULL,
+                                   ps->Endpoint, NULL, NULL, NULL);
+  if (status != RPC_S_OK)
+    return status;
 
   EnterCriticalSection(&server_cs);
-  ps->Next = protseqs;
-  protseqs = ps;
+  list_add_head(&protseqs, &ps->entry);
   LeaveCriticalSection(&server_cs);
 
-  if (std_listen) RPCRT4_sync_with_server_thread();
+  if (std_listen)
+  {
+    status = RPCRT4_start_listen_protseq(ps, FALSE);
+    if (status == RPC_S_OK)
+      RPCRT4_sync_with_server_thread(ps);
+  }
 
-  return RPC_S_OK;
+  return status;
 }
 
 /***********************************************************************
@@ -551,14 +533,14 @@ RPC_STATUS WINAPI RpcServerInqBindings( RPC_BINDING_VECTOR** BindingVector )
   EnterCriticalSection(&server_cs);
   /* count connections */
   count = 0;
-  ps = protseqs;
-  while (ps) {
+  LIST_FOR_EACH_ENTRY(ps, &protseqs, RpcServerProtseq, entry) {
+    EnterCriticalSection(&ps->cs);
     conn = ps->conn;
     while (conn) {
       count++;
       conn = conn->Next;
     }
-    ps = ps->Next;
+    LeaveCriticalSection(&ps->cs);
   }
   if (count) {
     /* export bindings */
@@ -567,8 +549,8 @@ RPC_STATUS WINAPI RpcServerInqBindings( RPC_BINDING_VECTOR** BindingVector )
                               sizeof(RPC_BINDING_HANDLE)*(count-1));
     (*BindingVector)->Count = count;
     count = 0;
-    ps = protseqs;
-    while (ps) {
+    LIST_FOR_EACH_ENTRY(ps, &protseqs, RpcServerProtseq, entry) {
+      EnterCriticalSection(&ps->cs);
       conn = ps->conn;
       while (conn) {
        RPCRT4_MakeBinding((RpcBinding**)&(*BindingVector)->BindingH[count],
@@ -576,7 +558,7 @@ RPC_STATUS WINAPI RpcServerInqBindings( RPC_BINDING_VECTOR** BindingVector )
        count++;
        conn = conn->Next;
       }
-      ps = ps->Next;
+      LeaveCriticalSection(&ps->cs);
     }
     status = RPC_S_OK;
   } else {
@@ -627,11 +609,24 @@ RPC_STATUS WINAPI RpcServerUseProtseqEpW( RPC_WSTR Protseq, UINT MaxCalls, RPC_W
 static RpcServerProtseq *alloc_serverprotoseq(UINT MaxCalls, char *Protseq, char *Endpoint)
 {
   RpcServerProtseq* ps;
+  const struct protseq_ops *ops = rpcrt4_get_protseq_ops(Protseq);
 
-  ps = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, sizeof(RpcServerProtseq));
+  if (!ops)
+    return NULL;
+
+  ps = ops->alloc();
+  if (!ps)
+    return NULL;
   ps->MaxCalls = MaxCalls;
   ps->Protseq = Protseq;
   ps->Endpoint = Endpoint;
+  ps->ops = ops;
+  ps->MaxCalls = 0;
+  ps->conn = NULL;
+  InitializeCriticalSection(&ps->cs);
+  ps->is_listening = FALSE;
+  ps->mgr_mutex = NULL;
+  ps->server_ready_event = NULL;
 
   return ps;
 }
@@ -758,13 +753,8 @@ RPC_STATUS WINAPI RpcServerRegisterIf2( RPC_IF_HANDLE IfSpec, UUID* MgrTypeUuid,
   ifs = sif;
   LeaveCriticalSection(&server_cs);
 
-  if (sif->Flags & RPC_IF_AUTOLISTEN) {
-    RPCRT4_start_listen(TRUE);
-
-    /* make sure server is actually listening on the interface before
-     * returning */
-    RPCRT4_sync_with_server_thread();
-  }
+  if (sif->Flags & RPC_IF_AUTOLISTEN)
+      RPCRT4_start_listen(TRUE);
 
   return RPC_S_OK;
 }
@@ -882,18 +872,15 @@ RPC_STATUS WINAPI RpcServerRegisterAuthInfoW( RPC_WSTR ServerPrincName, unsigned
  */
 RPC_STATUS WINAPI RpcServerListen( UINT MinimumCallThreads, UINT MaxCalls, UINT DontWait )
 {
-  RPC_STATUS status;
+  RPC_STATUS status = RPC_S_OK;
 
   TRACE("(%u,%u,%u)\n", MinimumCallThreads, MaxCalls, DontWait);
 
-  if (!protseqs)
+  if (list_empty(&protseqs))
     return RPC_S_NO_PROTSEQS_REGISTERED;
 
   status = RPCRT4_start_listen(FALSE);
 
-  if (status == RPC_S_OK)
-    RPCRT4_sync_with_server_thread();
-
   if (DontWait || (status != RPC_S_OK)) return status;
 
   return RpcMgmtWaitServerListen();
