@@ -104,7 +104,7 @@ SECURITY_STATUS fork_helper(PNegoHelper *new_helper, const char *prog,
 
         /* Whoops, we shouldn't get here. Big badaboom.*/
         write(STDOUT_FILENO, "BH\n", 3);
-        exit(1);
+        _exit(1);
     }
     else
     {
@@ -256,9 +256,10 @@ void cleanup_helper(PNegoHelper helper)
     TRACE("Killing helper %p\n", helper);
     if( (helper == NULL) || (helper->helper_pid == 0))
         return;
-      
+
     HeapFree(GetProcessHeap(), 0, helper->password);
     HeapFree(GetProcessHeap(), 0, helper->com_buf);
+    HeapFree(GetProcessHeap(), 0, helper->session_key);
 
     /* closing stdin will terminate ntlm_auth */
     close(helper->pipe_out);
