@@ -172,18 +172,12 @@ StringTableDestroy(HSTRING_TABLE hStringTable)
     {
         for (i = 0; i < pStringTable->dwMaxSlots; i++)
         {
-            if (pStringTable->pSlots[i].pString != NULL)
-            {
-                MyFree(pStringTable->pSlots[i].pString);
-                pStringTable->pSlots[i].pString = NULL;
-            }
+            MyFree(pStringTable->pSlots[i].pString);
+            pStringTable->pSlots[i].pString = NULL;
 
-            if (pStringTable->pSlots[i].pData != NULL)
-            {
-                MyFree(pStringTable->pSlots[i].pData);
-                pStringTable->pSlots[i].pData = NULL;
-                pStringTable->pSlots[i].dwSize = 0;
-            }
+            MyFree(pStringTable->pSlots[i].pData);
+            pStringTable->pSlots[i].pData = NULL;
+            pStringTable->pSlots[i].dwSize = 0;
         }
 
         MyFree(pStringTable->pSlots);
@@ -221,7 +215,7 @@ StringTableAddString(HSTRING_TABLE hStringTable,
     PSTRING_TABLE pStringTable;
     DWORD i;
 
-    TRACE("%p %s %lx\n", hStringTable, debugstr_w(lpString), dwFlags);
+    TRACE("%p %s %x\n", hStringTable, debugstr_w(lpString), dwFlags);
 
     pStringTable = (PSTRING_TABLE)hStringTable;
     if (pStringTable == NULL)
@@ -426,7 +420,7 @@ StringTableGetExtraData(HSTRING_TABLE hStringTable,
 {
     PSTRING_TABLE pStringTable;
 
-    TRACE("%p %lx %p %lu\n",
+    TRACE("%p %x %p %u\n",
           hStringTable, dwId, lpExtraData, dwExtraDataSize);
 
     pStringTable = (PSTRING_TABLE)hStringTable;
@@ -479,7 +473,7 @@ StringTableLookUpString(HSTRING_TABLE hStringTable,
     PSTRING_TABLE pStringTable;
     DWORD i;
 
-    TRACE("%p %s %lx\n", hStringTable, debugstr_w(lpString), dwFlags);
+    TRACE("%p %s %x\n", hStringTable, debugstr_w(lpString), dwFlags);
 
     pStringTable = (PSTRING_TABLE)hStringTable;
     if (pStringTable == NULL)
@@ -562,7 +556,7 @@ StringTableSetExtraData(HSTRING_TABLE hStringTable,
 {
     PSTRING_TABLE pStringTable;
 
-    TRACE("%p %lx %p %lu\n",
+    TRACE("%p %x %p %u\n",
           hStringTable, dwId, lpExtraData, dwExtraDataSize);
 
     pStringTable = (PSTRING_TABLE)hStringTable;
@@ -620,7 +614,7 @@ StringTableStringFromId(HSTRING_TABLE hStringTable,
     PSTRING_TABLE pStringTable;
     static WCHAR empty[] = {0};
 
-    TRACE("%p %lx\n", hStringTable, dwId);
+    TRACE("%p %x\n", hStringTable, dwId);
 
     pStringTable = (PSTRING_TABLE)hStringTable;
     if (pStringTable == NULL)
@@ -661,7 +655,7 @@ StringTableStringFromIdEx(HSTRING_TABLE hStringTable,
     DWORD dwLength;
     BOOL bResult = FALSE;
 
-    TRACE("%p %lx %p %p\n", hStringTable, dwId, lpBuffer, lpBufferLength);
+    TRACE("%p %x %p %p\n", hStringTable, dwId, lpBuffer, lpBufferLength);
 
     pStringTable = (PSTRING_TABLE)hStringTable;
     if (pStringTable == NULL)
