@@ -22,7 +22,6 @@
 #ifndef __WINE_SHDOCVW_H
 #define __WINE_SHDOCVW_H
 
-#define COM_NO_WINDOWS_H
 #define COBJMACROS
 
 #include <stdarg.h>
@@ -128,6 +127,7 @@ struct WebBrowser {
     VARIANT_BOOL address_bar;
     VARIANT_BOOL status_bar;
     VARIANT_BOOL tool_bar;
+    VARIANT_BOOL silent;
 
     DocHost doc_host;
 };
@@ -191,11 +191,13 @@ HRESULT WebBrowserV2_Create(IUnknown*,REFIID,void**);
 void create_doc_view_hwnd(DocHost*);
 void deactivate_document(DocHost*);
 void call_sink(ConnectionPoint*,DISPID,DISPPARAMS*);
-HRESULT navigate_url(DocHost*,LPCWSTR,PBYTE,ULONG,LPWSTR);
+HRESULT navigate_url(DocHost*,BSTR,VARIANT*,VARIANT*,VARIANT*,VARIANT*);
 
 HRESULT InternetExplorer_Create(IUnknown*,REFIID,void**);
 void InternetExplorer_WebBrowser_Init(InternetExplorer*);
 
+HRESULT CUrlHistory_Create(IUnknown*,REFIID,void**);
+
 #define WB_WM_NAVIGATE2 (WM_USER+100)
 
 #define DEFINE_THIS(cls,ifc,iface) ((cls*)((BYTE*)(iface)-offsetof(cls,lp ## ifc ## Vtbl)))
