@@ -335,6 +335,9 @@ static const WCHAR mimeImagePjpeg[] = {'i','m','a','g','e','/','p','j','p','e','
 static const WCHAR mimeImageGif[] = {'i','m','a','g','e','/','g','i','f',0};
 static const WCHAR mimeImageBmp[] = {'i','m','a','g','e','/','b','m','p',0};
 static const WCHAR mimeImageXPng[] = {'i','m','a','g','e','/','x','-','p','n','g',0};
+static const WCHAR mimeImageTiff[] = {'i','m','a','g','e','/','t','i','f','f',0};
+static const WCHAR mimeVideoAvi[] = {'v','i','d','e','o','/','a','v','i',0};
+static const WCHAR mimeVideoMpeg[] = {'v','i','d','e','o','/','m','p','e','g',0};
 
 static const struct {
     LPCWSTR url;
@@ -387,6 +390,22 @@ static BYTE data35[] = {0x89,'P','N','G',0x0d,0x0a,0x1a,0x0a,'x','x','x','x',0};
 static BYTE data36[] = {0x89,'P','N','G',0x0d,0x0a,0x1a,'x','x'};
 static BYTE data37[] = {0x89,'P','N','G',0x0d,0x0a,0x1a,0x0a,'<','h','t','m','l','>'};
 static BYTE data38[] = {0x00,0x89,'P','N','G',0x0d,0x0a,0x1a,0x0a,'x'};
+static BYTE data39[] = {0x4d,0x4d,0x00,0x2a};
+static BYTE data40[] = {0x4d,0x4d,0x00,0x2a,'<','h','t','m','l','>',0};
+static BYTE data41[] = {0x4d,0x4d,0xff};
+static BYTE data42[] = {0x4d,0x4d};
+static BYTE data43[] = {0x00,0x4d,0x4d,0x00};
+static BYTE data44[] = {'R','I','F','F',0xff,0xff,0xff,0xff,'A','V','I',0x20,0xff};
+static BYTE data45[] = {'R','I','F','f',0xff,0xff,0xff,0xff,'A','V','I',0x20,0xff};
+static BYTE data46[] = {'R','I','F','F',0xff,0xff,0xff,0xff,'A','V','I',0x20};
+static BYTE data47[] = {'R','I','F','F',0xff,0xff,0xff,0xff,'A','V','I',0x21,0xff};
+static BYTE data48[] = {'R','I','F','F',0xff,0xff,0xff,0xff,'A','V','I',0x20,'<','h','t','m','l','>'};
+static BYTE data49[] = {'R','I','F','F',0x0f,0x0f,0xf0,0xf0,'A','V','I',0x20,0xf0,0x00};
+static BYTE data50[] = {0x00,0x00,0x01,0xb3,0xff};
+static BYTE data51[] = {0x00,0x00,0x01,0xba,0xff};
+static BYTE data52[] = {0x00,0x00,0x01,0xb8,0xff};
+static BYTE data53[] = {0x00,0x00,0x01,0xba};
+static BYTE data54[] = {0x00,0x00,0x01,0xba,'<','h','t','m','l','>'};
 
 static const struct {
     BYTE *data;
@@ -430,7 +449,23 @@ static const struct {
     {data35, sizeof(data35), mimeImageXPng},
     {data36, sizeof(data36), mimeAppOctetStream},
     {data37, sizeof(data37), mimeTextHtml},
-    {data38, sizeof(data38), mimeAppOctetStream}
+    {data38, sizeof(data38), mimeAppOctetStream},
+    {data39, sizeof(data39), mimeImageTiff},
+    {data40, sizeof(data40), mimeTextHtml},
+    {data41, sizeof(data41), mimeImageTiff},
+    {data42, sizeof(data42), mimeTextPlain},
+    {data43, sizeof(data43), mimeAppOctetStream},
+    {data44, sizeof(data44), mimeVideoAvi},
+    {data45, sizeof(data45), mimeTextPlain},
+    {data46, sizeof(data46), mimeTextPlain},
+    {data47, sizeof(data47), mimeTextPlain},
+    {data48, sizeof(data48), mimeTextHtml},
+    {data49, sizeof(data49), mimeVideoAvi},
+    {data50, sizeof(data50), mimeVideoMpeg},
+    {data51, sizeof(data51), mimeVideoMpeg},
+    {data52, sizeof(data52), mimeAppOctetStream},
+    {data53, sizeof(data53), mimeAppOctetStream},
+    {data54, sizeof(data54), mimeTextHtml}
 };
 
 static void test_FindMimeFromData(void)
