@@ -48,14 +48,14 @@ static HRESULT WINAPI IWineD3DTextureImpl_QueryInterface(IWineD3DTexture *iface,
 
 static ULONG WINAPI IWineD3DTextureImpl_AddRef(IWineD3DTexture *iface) {
     IWineD3DTextureImpl *This = (IWineD3DTextureImpl *)iface;
-    TRACE("(%p) : AddRef increasing from %ld\n", This, This->resource.ref);
+    TRACE("(%p) : AddRef increasing from %d\n", This, This->resource.ref);
     return InterlockedIncrement(&This->resource.ref);
 }
 
 static ULONG WINAPI IWineD3DTextureImpl_Release(IWineD3DTexture *iface) {
     IWineD3DTextureImpl *This = (IWineD3DTextureImpl *)iface;
     ULONG ref;
-    TRACE("(%p) : Releasing from %ld\n", This, This->resource.ref);
+    TRACE("(%p) : Releasing from %d\n", This, This->resource.ref);
     ref = InterlockedDecrement(&This->resource.ref);
     if (ref == 0) {
         int i;
@@ -65,7 +65,7 @@ static ULONG WINAPI IWineD3DTextureImpl_Release(IWineD3DTexture *iface) {
             if (This->surfaces[i] != NULL) {
                 /* Because the surfaces were created using a callback we need to release there parent otehrwise we leave the parent hanging */
                 IUnknown* surfaceParent;
-                /* Clean out the texture name we gave to the suface so that the surface doesn't try and release it */
+                /* Clean out the texture name we gave to the surface so that the surface doesn't try and release it */
                 IWineD3DSurface_SetGlTextureDesc(This->surfaces[i], 0, 0);
                 /* Cleanup the container */
                 IWineD3DSurface_SetContainer(This->surfaces[i], 0);
@@ -124,7 +124,7 @@ static void WINAPI IWineD3DTextureImpl_PreLoad(IWineD3DTexture *iface) {
     IWineD3DTexture_BindTexture(iface);
     ENTER_GL();
         /* If were dirty then reload the surfaces */
-    if(This->baseTexture.dirty != FALSE) {
+    if(This->baseTexture.dirty) {
 
         for (i = 0; i < This->baseTexture.levels; i++) {
             if(setGlTextureDesc)
@@ -216,7 +216,7 @@ static void WINAPI IWineD3DTextureImpl_ApplyStateChanges(IWineD3DTexture *iface,
     if(This->pow2scalingFactorX != 1.0f || This->pow2scalingFactorY != 1.0f) {
         /* Apply non-power2 mappings and texture offsets so long as the texture coords aren't projected or generated */
         if(((textureStates[WINED3DTSS_TEXCOORDINDEX] & 0xFFFF0000) == D3DTSS_TCI_PASSTHRU) &&
-                      (~textureStates[WINED3DTSS_TEXTURETRANSFORMFLAGS] & D3DTTFF_PROJECTED)) {
+                      (~textureStates[WINED3DTSS_TEXTURETRANSFORMFLAGS] & WINED3DTTFF_PROJECTED)) {
             glMatrixMode(GL_TEXTURE);
             memset(matrix, 0 , sizeof(matrix));
             matrix[0] = This->pow2scalingFactorX;
