@@ -1272,44 +1272,6 @@ BOOL WINAPI X11DRV_wglDeleteContext(HGLRC hglrc)
     return ret;
 }
 
-/* OpenGL32 wglGetCurrentContext() */
-HGLRC WINAPI X11DRV_wglGetCurrentContext(void) {
-    GLXContext gl_ctx;
-    Wine_GLContext *ret;
-
-    TRACE("()\n");
-
-    wine_tsx11_lock();
-    gl_ctx = pglXGetCurrentContext();
-    ret = get_context_from_GLXContext(gl_ctx);
-    wine_tsx11_unlock();
-
-    TRACE(" returning %p (GL context %p)\n", ret, gl_ctx);
-
-    return (HGLRC)ret;
-}
-
-/* OpenGL32 wglGetCurrentDC */
-HDC WINAPI X11DRV_wglGetCurrentDC(void) {
-    GLXContext gl_ctx;
-    Wine_GLContext *ret;
-
-    TRACE("()\n");
-
-    wine_tsx11_lock();
-    gl_ctx = pglXGetCurrentContext();
-    ret = get_context_from_GLXContext(gl_ctx);
-    wine_tsx11_unlock();
-
-    if (ret) {
-        TRACE(" returning %p (GL context %p - Wine context %p)\n", ret->hdc, gl_ctx, ret);
-        return ret->hdc;
-    } else {
-        TRACE(" no Wine context found for GLX context %p\n", gl_ctx);
-        return 0;
-    }
-}
-
 /* OpenGL32 wglGetCurrentReadDCARB */
 static HDC WINAPI X11DRV_wglGetCurrentReadDCARB(void) 
 {
@@ -1337,19 +1299,24 @@ PROC X11DRV_wglGetProcAddress(LPCSTR lpszProc)
     if (padding < 0)
         padding = 0;
 
-    TRACE("('%s'):%*s", lpszProc, padding, " ");
-    for (i = 0; i < WineGLExtensionListSize; ++i) {
-        ext = WineGLExtensionList[i];
-        for (j = 0; ext->extEntryPoints[j].funcName; ++j) {
-            if (strcmp(ext->extEntryPoints[j].funcName, lpszProc) == 0) {
-                TRACE("(%p) - WineGL\n", ext->extEntryPoints[j].funcAddress);
-                return ext->extEntryPoints[j].funcAddress;
+    /* Check the table of WGL extensions to see if we need to return a WGL extension
+     * or a function pointer to a native OpenGL function. */
+    if(strncmp(lpszProc, "wgl", 3) != 0) {
+        return pglXGetProcAddressARB((GLubyte*)lpszProc);
+    } else {
+        TRACE("('%s'):%*s", lpszProc, padding, " ");
+        for (i = 0; i < WineGLExtensionListSize; ++i) {
+            ext = WineGLExtensionList[i];
+            for (j = 0; ext->extEntryPoints[j].funcName; ++j) {
+                if (strcmp(ext->extEntryPoints[j].funcName, lpszProc) == 0) {
+                    TRACE("(%p) - WineGL\n", ext->extEntryPoints[j].funcAddress);
+                    return ext->extEntryPoints[j].funcAddress;
+                }
             }
         }
     }
 
     ERR("(%s) - not found\n", lpszProc);
-
     return NULL;
 }
 
@@ -1417,6 +1384,7 @@ static BOOL WINAPI X11DRV_wglMakeContextCurrentARB(HDC hDrawDC, HDC hReadDC, HGL
     wine_tsx11_lock();
     if (hglrc == NULL) {
         ret = pglXMakeCurrent(gdi_display, None, NULL);
+        NtCurrentTeb()->glContext = NULL;
     } else {
         if (NULL == pglXMakeContextCurrent) {
             ret = FALSE;
@@ -1430,6 +1398,7 @@ static BOOL WINAPI X11DRV_wglMakeContextCurrentARB(HDC hDrawDC, HDC hReadDC, HGL
                 TRACE(" created a delayed OpenGL context (%p)\n", ctx->ctx);
             }
             ret = pglXMakeContextCurrent(ctx->display, d_draw, d_read, ctx->ctx);
+            NtCurrentTeb()->glContext = ctx;
         }
     }
     wine_tsx11_unlock();
@@ -2368,8 +2337,8 @@ static GLboolean WINAPI X11DRV_wglBindTexImageARB(HPBUFFERARB hPbuffer, int iBuf
             object->render_ctx = wglCreateContext(object->render_hdc);
             do_init = 1;
         }
-        object->prev_hdc = X11DRV_wglGetCurrentDC();
-        object->prev_ctx = X11DRV_wglGetCurrentContext();
+        object->prev_hdc = wglGetCurrentDC();
+        object->prev_ctx = wglGetCurrentContext();
         /* FIXME: This is routed through gdi32.dll to winex11.drv, replace this with GLX calls */
         wglMakeCurrent(object->render_hdc, object->render_ctx);
         /*
@@ -2493,6 +2462,15 @@ static BOOL register_extension(const WineGLExtension * ext)
     return TRUE;
 }
 
+static const WineGLExtension WGL_internal_functions =
+{
+  "",
+  {
+    { "wglGetIntegerv", X11DRV_wglGetIntegerv },
+  }
+};
+
+
 static const WineGLExtension WGL_ARB_extensions_string =
 {
   "WGL_ARB_extensions_string",
@@ -2572,6 +2550,9 @@ static void X11DRV_WineGL_LoadExtensions(void)
 {
     WineGLInfo.wglExtensions[0] = 0;
 
+    /* Load Wine internal functions */
+    register_extension(&WGL_internal_functions);
+
     /* ARB Extensions */
 
     register_extension(&WGL_ARB_extensions_string);
@@ -2799,18 +2780,6 @@ BOOL WINAPI X11DRV_wglDeleteContext(HGLRC hglrc) {
     return FALSE;
 }
 
-/* OpenGL32 wglGetCurrentContext() */
-HGLRC WINAPI X11DRV_wglGetCurrentContext(void) {
-    ERR_(opengl)("No OpenGL support compiled in.\n");
-    return NULL;
-}
-
-/* OpenGL32 wglGetCurrentDC */
-HDC WINAPI X11DRV_wglGetCurrentDC(void) {
-    ERR_(opengl)("No OpenGL support compiled in.\n");
-    return 0;
-}
-
 /* OpenGL32: wglGetProcAddress */
 PROC X11DRV_wglGetProcAddress(LPCSTR lpszProc) {
     ERR_(opengl)("No OpenGL support compiled in.\n");
@@ -2843,11 +2812,6 @@ BOOL WINAPI X11DRV_wglUseFontBitmapsW(HDC hdc, DWORD first, DWORD count, DWORD l
     return FALSE;
 }
 
-/* WGL helper function which handles differences in glGetIntegerv from WGL and GLX */ 
-void X11DRV_wglGetIntegerv(int pname, int* params) {
-    ERR_(opengl)("No OpenGL support compiled in.\n");
-}
-
 XVisualInfo *X11DRV_setup_opengl_visual( Display *display )
 {
   return NULL;
