@@ -102,6 +102,9 @@ void X11DRV_Expose( HWND hwnd, XEvent *xev )
     rect.right  = rect.left + event->width;
     rect.bottom = rect.top + event->height;
 
+    if (event->window == root_window)
+        OffsetRect( &rect, virtual_screen_rect.left, virtual_screen_rect.top );
+
     if (rect.left < data->client_rect.left ||
         rect.top < data->client_rect.top ||
         rect.right > data->client_rect.right ||
@@ -938,7 +941,7 @@ UINT WINPOS_MinMaximize( HWND hwnd, UINT cmd, LPRECT rect )
 
     case SW_MAXIMIZE:
         old_style = GetWindowLongW( hwnd, GWL_STYLE );
-        if ((old_style & WS_MAXIMIZE) && (old_style & WS_CHILD)) return SWP_NOSIZE | SWP_NOMOVE;
+        if ((old_style & WS_MAXIMIZE) && (old_style & WS_VISIBLE)) return SWP_NOSIZE | SWP_NOMOVE;
 
         WINPOS_GetMinMaxInfo( hwnd, &size, &wpl.ptMaxPosition, NULL, NULL );
 
@@ -1029,7 +1032,7 @@ BOOL X11DRV_ShowWindow( HWND hwnd, INT cmd )
 	case SW_SHOWMAXIMIZED: /* same as SW_MAXIMIZE */
             swp |= SWP_SHOWWINDOW | SWP_FRAMECHANGED;
             swp |= WINPOS_MinMaximize( hwnd, SW_MAXIMIZE, &newPos );
-            if ((style & WS_MAXIMIZE) && (style & WS_CHILD)) return wasVisible;
+            if ((style & WS_MAXIMIZE) && wasVisible) return wasVisible;
             state_change = TRUE;
             break;
 
@@ -1168,6 +1171,7 @@ void X11DRV_MapNotify( HWND hwnd, XEvent *event )
         rect.top    = y;
         rect.right  = x + width;
         rect.bottom = y + height;
+        OffsetRect( &rect, virtual_screen_rect.left, virtual_screen_rect.top );
         X11DRV_X_to_window_rect( data, &rect );
 
         invalidate_dce( hwnd, &data->window_rect );
@@ -1253,10 +1257,11 @@ void X11DRV_handle_desktop_resize( unsigned int width, unsigned int height )
 
     screen_width  = width;
     screen_height = height;
+    xinerama_init();
     TRACE("desktop %p change to (%dx%d)\n", hwnd, width, height);
-    SetRect( &rect, 0, 0, width, height );
     data->lock_changes++;
-    X11DRV_set_window_pos( hwnd, 0, &rect, &rect, SWP_NOZORDER|SWP_NOMOVE, NULL );
+    X11DRV_set_window_pos( hwnd, 0, &virtual_screen_rect, &virtual_screen_rect,
+                           SWP_NOZORDER|SWP_NOMOVE, NULL );
     data->lock_changes--;
     SendMessageTimeoutW( HWND_BROADCAST, WM_DISPLAYCHANGE, screen_depth,
                          MAKELPARAM( width, height ), SMTO_ABORTIFHUNG, 2000, NULL );
@@ -1294,6 +1299,7 @@ void X11DRV_ConfigureNotify( HWND hwnd, XEvent *xev )
     rect.top    = y;
     rect.right  = x + event->width;
     rect.bottom = y + event->height;
+    OffsetRect( &rect, virtual_screen_rect.left, virtual_screen_rect.top );
     TRACE( "win %p new X rect %d,%d,%dx%d (event %d,%d,%dx%d)\n",
            hwnd, rect.left, rect.top, rect.right-rect.left, rect.bottom-rect.top,
            event->x, event->y, event->width, event->height );
@@ -1665,7 +1671,7 @@ void X11DRV_SysCommandSizeMove( HWND hwnd, WPARAM wParam )
     else
     {
         parent = 0;
-        SetRect(&mouseRect, 0, 0, GetSystemMetrics(SM_CXSCREEN), GetSystemMetrics(SM_CYSCREEN));
+        mouseRect = virtual_screen_rect;
     }
     origRect = sizingRect;
 
