@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #ifndef __WINE_OLEDLG_H
@@ -41,56 +41,6 @@ typedef struct IOleUIObjInfoW *POLEUIOBJINFOW, *LPOLEUIOBJINFOW;
 
 #define IDC_OLEUIHELP                   99
 
-/* Change Source Dialog flags */
-#define CSF_SHOWHELP                    0x00000001L
-#define CSF_VALIDSOURCE                 0x00000002L
-#define CSF_ONLYGETSOURCE               0x00000004L
-#define CSF_EXPLORER                    0x00000008L
-
-#define PSF_SHOWHELP                    0x00000001L
-#define PSF_SELECTPASTE                 0x00000002L
-#define PSF_SELECTPASTELINK             0x00000004L
-#define PSF_CHECKDISPLAYASICON          0x00000008L
-#define PSF_DISABLEDISPLAYASICON        0x00000010L
-#define PSF_HIDECHANGEICON              0x00000020L
-#define PSF_STAYONCLIPBOARDCHANGE       0x00000040L
-#define PSF_NOREFRESHDATAOBJECT         0x00000080L
-
-#define IOF_SHOWHELP                    0x00000001L
-#define IOF_SELECTCREATENEW             0x00000002L
-#define IOF_SELECTCREATEFROMFILE        0x00000004L
-#define IOF_CHECKLINK                   0x00000008L
-#define IOF_CHECKDISPLAYASICON          0x00000010L
-#define IOF_CREATENEWOBJECT             0x00000020L
-#define IOF_CREATEFILEOBJECT            0x00000040L
-#define IOF_CREATELINKOBJECT            0x00000080L
-#define IOF_DISABLELINK                 0x00000100L
-#define IOF_VERIFYSERVERSEXIST          0x00000200L
-#define IOF_DISABLEDISPLAYASICON        0x00000400L
-#define IOF_HIDECHANGEICON              0x00000800L
-#define IOF_SHOWINSERTCONTROL           0x00001000L
-#define IOF_SELECTCREATECONTROL         0x00002000L
-
-#define CF_SHOWHELPBUTTON               0x00000001L
-#define CF_SETCONVERTDEFAULT            0x00000002L
-#define CF_SETACTIVATEDEFAULT           0x00000004L
-#define CF_SELECTCONVERTTO              0x00000008L
-#define CF_SELECTACTIVATEAS             0x00000010L
-#define CF_DISABLEDISPLAYASICON         0x00000020L
-#define CF_DISABLEACTIVATEAS            0x00000040L
-#define CF_HIDECHANGEICON               0x00000080L
-#define CF_CONVERTONLY                  0x00000100L
-
-#define CIF_SHOWHELP                    0x00000001L
-#define CIF_SELECTCURRENT               0x00000002L
-#define CIF_SELECTDEFAULT               0x00000004L
-#define CIF_SELECTFROMFILE              0x00000008L
-#define CIF_USEICONEXE                  0x00000010L
-
-#define BZ_DISABLECANCELBUTTON          0x00000001L
-#define BZ_DISABLESWITCHTOBUTTON        0x00000002L
-#define BZ_DISABLERETRYBUTTON           0x00000004L
-#define BZ_NOTRESPONDINGDIALOG          0x00000008L
 
 #define OLEUI_ERR_STANDARDMAX           116
 
@@ -123,13 +73,62 @@ typedef struct IOleUIObjInfoW *POLEUIOBJINFOW, *LPOLEUIOBJINFOW;
 #define OLEUI_ERR_LOADSTRING            115
 #define OLEUI_ERR_STANDARDMAX           116
 
-#define OPF_OBJECTISLINK                0x00000001L
-#define OPF_NOFILLDEFAULT               0x00000002L
-#define OPF_SHOWHELP                    0x00000004L
-#define OPF_DISABLECONVERT              0x00000008L
-
 typedef UINT (CALLBACK *LPFNOLEUIHOOK)(HWND, UINT, WPARAM, LPARAM);
 
+/*****************************************************************************
+ * Registered Message Names
+ */
+#define SZOLEUI_MSG_HELPA              "OLEUI_MSG_HELP"
+#define SZOLEUI_MSG_ENDDIALOGA         "OLEUI_MSG_ENDDIALOG"
+#define SZOLEUI_MSG_BROWSEA            "OLEUI_MSG_BROWSE"
+#define SZOLEUI_MSG_CHANGEICONA        "OLEUI_MSG_CHANGEICON"
+#define SZOLEUI_MSG_CLOSEBUSYDIALOGA   "OLEUI_MSG_CLOSEBUSYDIALOG"
+#define SZOLEUI_MSG_CONVERTA           "OLEUI_MSG_CONVERT"
+#define SZOLEUI_MSG_CHANGESOURCEA      "OLEUI_MSG_CHANGESOURCE"
+#define SZOLEUI_MSG_ADDCONTROLA        "OLEUI_MSG_ADDCONTROL"
+#define SZOLEUI_MSG_BROWSE_OFNA        "OLEUI_MSG_BROWSE_OFN"
+#if defined(__GNUC__)
+# define SZOLEUI_MSG_HELPW             (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','H','E','L','P',0 }
+# define SZOLEUI_MSG_ENDDIALOGW        (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','E','N','D','D','I','A','L','O','G',0 }
+# define SZOLEUI_MSG_BROWSEW           (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','B','R','O','W','S','E',0 }
+# define SZOLEUI_MSG_CHANGEICONW       (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','C','H','A','N','G','E','I','C','O','N',0 }
+# define SZOLEUI_MSG_CLOSEBUSYDIALOGW  (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','C','L','O','S','E','B','U','S','Y','D','I','A','L','O','G',0 }
+# define SZOLEUI_MSG_CONVERTW          (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','C','O','N','V','E','R','T',0 }
+# define SZOLEUI_MSG_CHANGESOURCEW     (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','C','H','A','N','G','E','S','O','U','R','C','E',0 }
+# define SZOLEUI_MSG_ADDCONTROLW       (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','A','D','D','C','O','N','T','R','O','L',0 }
+# define SZOLEUI_MSG_BROWSE_OFNW       (const WCHAR []){ 'O','L','E','U','I','_','M','S','G','_','B','R','O','W','S','E','_','O','F','N',0 }
+#elif defined(_MSC_VER)
+# define SZOLEUI_MSG_HELPW              L"OLEUI_MSG_HELP"
+# define SZOLEUI_MSG_ENDDIALOGW         L"OLEUI_MSG_ENDDIALOG"
+# define SZOLEUI_MSG_BROWSEW            L"OLEUI_MSG_BROWSE"
+# define SZOLEUI_MSG_CHANGEICONW        L"OLEUI_MSG_CHANGEICON"
+# define SZOLEUI_MSG_CLOSEBUSYDIALOGW   L"OLEUI_MSG_CLOSEBUSYDIALOG"
+# define SZOLEUI_MSG_CONVERTW           L"OLEUI_MSG_CONVERT"
+# define SZOLEUI_MSG_CHANGESOURCEW      L"OLEUI_MSG_CHANGESOURCE"
+# define SZOLEUI_MSG_ADDCONTROLW        L"OLEUI_MSG_ADDCONTROL"
+# define SZOLEUI_MSG_BROWSE_OFNW        L"OLEUI_MSG_BROWSE_OFN"
+#else
+static const WCHAR SZOLEUI_MSG_HELPW[]             = { 'O','L','E','U','I','_','M','S','G','_','H','E','L','P',0 };
+static const WCHAR SZOLEUI_MSG_ENDDIALOGW[]        = { 'O','L','E','U','I','_','M','S','G','_','E','N','D','D','I','A','L','O','G',0 };
+static const WCHAR SZOLEUI_MSG_BROWSEW[]           = { 'O','L','E','U','I','_','M','S','G','_','B','R','O','W','S','E',0 };
+static const WCHAR SZOLEUI_MSG_CHANGEICONW[]       = { 'O','L','E','U','I','_','M','S','G','_','C','H','A','N','G','E','I','C','O','N',0 };
+static const WCHAR SZOLEUI_MSG_CLOSEBUSYDIALOGW[]  = { 'O','L','E','U','I','_','M','S','G','_','C','L','O','S','E','B','U','S','Y','D','I','A','L','O','G',0 };
+static const WCHAR SZOLEUI_MSG_CONVERTW[]          = { 'O','L','E','U','I','_','M','S','G','_','C','O','N','V','E','R','T',0 };
+static const WCHAR SZOLEUI_MSG_CHANGESOURCEW[]     = { 'O','L','E','U','I','_','M','S','G','_','C','H','A','N','G','E','S','O','U','R','C','E',0 };
+static const WCHAR SZOLEUI_MSG_ADDCONTROLW[]       = { 'O','L','E','U','I','_','M','S','G','_','A','D','D','C','O','N','T','R','O','L',0 };
+static const WCHAR SZOLEUI_MSG_BROWSE_OFNW[]       = { 'O','L','E','U','I','_','M','S','G','_','B','R','O','W','S','E','_','O','F','N',0 };
+#endif
+#define SZOLEUI_MSG_HELP             WINELIB_NAME_AW(SZOLEUI_MSG_HELP)
+#define SZOLEUI_MSG_ENDDIALOG        WINELIB_NAME_AW(SZOLEUI_MSG_ENDDIALOG)
+#define SZOLEUI_MSG_BROWSE           WINELIB_NAME_AW(SZOLEUI_MSG_BROWSE)
+#define SZOLEUI_MSG_CHANGEICON       WINELIB_NAME_AW(SZOLEUI_MSG_CHANGEICON)
+#define SZOLEUI_MSG_CLOSEBUSYDIALOG  WINELIB_NAME_AW(SZOLEUI_MSG_CLOSEBUSYDIALOG)
+#define SZOLEUI_MSG_CONVERT          WINELIB_NAME_AW(SZOLEUI_MSG_CONVERT)
+#define SZOLEUI_MSG_CHANGESOURCE     WINELIB_NAME_AW(SZOLEUI_MSG_CHANGESOURCE)
+#define SZOLEUI_MSG_ADDCONTROL       WINELIB_NAME_AW(SZOLEUI_MSG_ADDCONTROL)
+#define SZOLEUI_MSG_BROWSE_OFN       WINELIB_NAME_AW(SZOLEUI_MSG_BROWSE_OFN)
+
+
 /*****************************************************************************
  * INSERT OBJECT DIALOG
  */
@@ -189,6 +188,20 @@ DECL_WINELIB_TYPE_AW(OLEUIINSERTOBJECT)
 DECL_WINELIB_TYPE_AW(POLEUIINSERTOBJECT)
 DECL_WINELIB_TYPE_AW(LPOLEUIINSERTOBJECT)
 
+#define IOF_SHOWHELP                    0x00000001L
+#define IOF_SELECTCREATENEW             0x00000002L
+#define IOF_SELECTCREATEFROMFILE        0x00000004L
+#define IOF_CHECKLINK                   0x00000008L
+#define IOF_CHECKDISPLAYASICON          0x00000010L
+#define IOF_CREATENEWOBJECT             0x00000020L
+#define IOF_CREATEFILEOBJECT            0x00000040L
+#define IOF_CREATELINKOBJECT            0x00000080L
+#define IOF_DISABLELINK                 0x00000100L
+#define IOF_VERIFYSERVERSEXIST          0x00000200L
+#define IOF_DISABLEDISPLAYASICON        0x00000400L
+#define IOF_HIDECHANGEICON              0x00000800L
+#define IOF_SHOWINSERTCONTROL           0x00001000L
+#define IOF_SELECTCREATECONTROL         0x00002000L
 
 /*****************************************************************************
  * CONVERT DIALOG
@@ -249,6 +262,16 @@ DECL_WINELIB_TYPE_AW(OLEUICONVERT)
 DECL_WINELIB_TYPE_AW(POLEUICONVERT)
 DECL_WINELIB_TYPE_AW(LPOLEUICONVERT)
 
+#define CF_SHOWHELPBUTTON               0x00000001L
+#define CF_SETCONVERTDEFAULT            0x00000002L
+#define CF_SETACTIVATEDEFAULT           0x00000004L
+#define CF_SELECTCONVERTTO              0x00000008L
+#define CF_SELECTACTIVATEAS             0x00000010L
+#define CF_DISABLEDISPLAYASICON         0x00000020L
+#define CF_DISABLEACTIVATEAS            0x00000040L
+#define CF_HIDECHANGEICON               0x00000080L
+#define CF_CONVERTONLY                  0x00000100L
+
 /*****************************************************************************
  * CHANGE ICON DIALOG
  */
@@ -291,6 +314,12 @@ DECL_WINELIB_TYPE_AW(POLEUICHANGEICON)
 DECL_WINELIB_TYPE_AW(LPOLEUICHANGEICON)
 
 
+#define CIF_SHOWHELP                    0x00000001L
+#define CIF_SELECTCURRENT               0x00000002L
+#define CIF_SELECTDEFAULT               0x00000004L
+#define CIF_SELECTFROMFILE              0x00000008L
+#define CIF_USEICONEXE                  0x00000010L
+
 /*****************************************************************************
  * PASTE SPECIAL DIALOG
  */
@@ -385,6 +414,8 @@ DECL_WINELIB_TYPE_AW(OLEUIPASTESPECIAL)
 DECL_WINELIB_TYPE_AW(POLEUIPASTESPECIAL)
 DECL_WINELIB_TYPE_AW(LPOLEUIPASTESPECIAL)
 
+#define PS_MAXLINKTYPES                 8
+
 #define PSF_SHOWHELP                    0x00000001L
 #define PSF_SELECTPASTE                 0x00000002L
 #define PSF_SELECTPASTELINK             0x00000004L
@@ -401,6 +432,27 @@ DECL_WINELIB_TYPE_AW(LPOLEUIPASTESPECIAL)
 #define OLEUI_PSERR_CLIPBOARDCHANGED        (OLEUI_ERR_STANDARDMAX+3)
 #define OLEUI_PSERR_GETCLIPBOARDFAILED      (OLEUI_ERR_STANDARDMAX+4)
 
+/* Paste Special dialog resource ids */
+#define IDD_PASTESPECIAL       1003
+#define IDD_PASTESPECIAL4      1108
+
+/* Paste Special dialog control ids */
+#define IDC_PS_PASTE           500
+#define IDC_PS_PASTELINK       501
+#define IDC_PS_SOURCETEXT      502
+#define IDC_PS_PASTELIST       503
+#define IDC_PS_PASTELINKLIST   504
+#define IDC_PS_DISPLAYLIST     505
+#define IDC_PS_DISPLAYASICON   506
+#define IDC_PS_ICONDISPLAY     507
+#define IDC_PS_CHANGEICON      508
+#define IDC_PS_RESULTIMAGE     509
+#define IDC_PS_RESULTTEXT      510
+
+/*****************************************************************************
+ * EDIT LINKS DIALOG
+ */
+
 #define ELF_SHOWHELP               0x00000001L
 #define ELF_DISABLEUPDATENOW       0x00000002L
 #define ELF_DISABLEOPENSOURCE      0x00000004L
@@ -478,6 +530,15 @@ DECL_WINELIB_TYPE_AW(POLEUIBUSY)
 DECL_WINELIB_TYPE_AW(LPOLEUIBUSY)
 
 
+#define BZ_DISABLECANCELBUTTON          0x00000001L
+#define BZ_DISABLESWITCHTOBUTTON        0x00000002L
+#define BZ_DISABLERETRYBUTTON           0x00000004L
+#define BZ_NOTRESPONDINGDIALOG          0x00000008L
+
+/***********************************************************************************
+ * OBJECT PROPERTIES DIALOG
+ */
+
 struct tagOLEUIOBJECTPROPSW;
 struct tagOLEUIOBJECTPROPSA;
 
@@ -601,6 +662,12 @@ DECL_WINELIB_TYPE_AW(OLEUIOBJECTPROPS)
 DECL_WINELIB_TYPE_AW(POLEUIOBJECTPROPS)
 DECL_WINELIB_TYPE_AW(LPOLEUIOBJECTPROPS)
 
+#define OPF_OBJECTISLINK                0x00000001L
+#define OPF_NOFILLDEFAULT               0x00000002L
+#define OPF_SHOWHELP                    0x00000004L
+#define OPF_DISABLECONVERT              0x00000008L
+
+
 /************************************************************************************
  * CHANGE SOURCE DIALOG
  */
@@ -654,6 +721,12 @@ DECL_WINELIB_TYPE_AW(OLEUICHANGESOURCE)
 DECL_WINELIB_TYPE_AW(POLEUICHANGESOURCE)
 DECL_WINELIB_TYPE_AW(LPOLEUICHANGESOURCE)
 
+/* Change Source Dialog flags */
+#define CSF_SHOWHELP                    0x00000001L
+#define CSF_VALIDSOURCE                 0x00000002L
+#define CSF_ONLYGETSOURCE               0x00000004L
+#define CSF_EXPLORER                    0x00000008L
+
 
 /*****************************************************************************
  * IOleUILinkContainer interface
