@@ -442,6 +442,25 @@ typedef enum _WINED3DRENDERSTATETYPE {
 #define WINEHIGHEST_RENDER_STATE   WINED3DRS_BLENDOPALPHA
         /* Highest WINED3DRS_ value   */
 
+typedef enum _WINED3DBLEND {
+    WINED3DBLEND_ZERO               =  1,
+    WINED3DBLEND_ONE                =  2,
+    WINED3DBLEND_SRCCOLOR           =  3,
+    WINED3DBLEND_INVSRCCOLOR        =  4,
+    WINED3DBLEND_SRCALPHA           =  5,
+    WINED3DBLEND_INVSRCALPHA        =  6,
+    WINED3DBLEND_DESTALPHA          =  7,
+    WINED3DBLEND_INVDESTALPHA       =  8,
+    WINED3DBLEND_DESTCOLOR          =  9,
+    WINED3DBLEND_INVDESTCOLOR       = 10,
+    WINED3DBLEND_SRCALPHASAT        = 11,
+    WINED3DBLEND_BOTHSRCALPHA       = 12,
+    WINED3DBLEND_BOTHINVSRCALPHA    = 13,
+    WINED3DBLEND_BLENDFACTOR        = 14,
+    WINED3DBLEND_INVBLENDFACTOR     = 15,
+    WINED3DBLEND_FORCE_DWORD        = 0x7fffffff
+} WINED3DBLEND;
+
 typedef enum _WINED3DVERTEXBLENDFLAGS {
     WINED3DVBF_DISABLE  =   0,
     WINED3DVBF_1WEIGHTS =   1,
@@ -451,6 +470,14 @@ typedef enum _WINED3DVERTEXBLENDFLAGS {
     WINED3DVBF_0WEIGHTS = 256
 } WINED3DVERTEXBLENDFLAGS;
 
+typedef enum _WINED3DZBUFFERTYPE {
+    WINED3DZB_FALSE                 = 0,
+    WINED3DZB_TRUE                  = 1,
+    WINED3DZB_USEW                  = 2,
+
+    WINED3DZB_FORCE_DWORD           = 0x7fffffff
+} WINED3DZBUFFERTYPE;
+
 typedef struct _WINED3DDISPLAYMODE {
     UINT            Width;
     UINT            Height;
@@ -593,6 +620,27 @@ typedef enum _WINED3DTEXTUREOP {
     WINED3DTOP_FORCE_DWORD               = 0x7fffffff,
 } WINED3DTEXTUREOP;
 
+#define WINED3DTA_SELECTMASK        0x0000000f
+#define WINED3DTA_DIFFUSE           0x00000000
+#define WINED3DTA_CURRENT           0x00000001
+#define WINED3DTA_TEXTURE           0x00000002
+#define WINED3DTA_TFACTOR           0x00000003
+#define WINED3DTA_SPECULAR          0x00000004
+#define WINED3DTA_TEMP              0x00000005
+#define WINED3DTA_CONSTANT          0x00000006
+#define WINED3DTA_COMPLEMENT        0x00000010
+#define WINED3DTA_ALPHAREPLICATE    0x00000020
+
+typedef enum _WINED3DTEXTUREADDRESS {
+    WINED3DTADDRESS_WRAP            = 1,
+    WINED3DTADDRESS_MIRROR          = 2,
+    WINED3DTADDRESS_CLAMP           = 3,
+    WINED3DTADDRESS_BORDER          = 4,
+    WINED3DTADDRESS_MIRRORONCE      = 5,
+
+    WINED3DTADDRESS_FORCE_DWORD     = 0x7fffffff
+} WINED3DTEXTUREADDRESS;
+
 typedef enum _WINED3DTRANSFORMSTATETYPE {
     WINED3DTS_VIEW            =  2,
     WINED3DTS_PROJECTION      =  3,
