@@ -272,6 +272,7 @@ static BOOL WINHELP_RegisterWinClasses(void)
 
     class_text = class_main;
     class_text.lpfnWndProc         = WINHELP_TextWndProc;
+    class_text.hbrBackground       = 0;
     class_text.lpszClassName       = TEXT_WIN_CLASS_NAME;
 
     class_shadow = class_main;
@@ -361,6 +362,7 @@ static LRESULT  WINHELP_HandleCommand(HWND hSrcWnd, LPARAM lParam)
         /* case HELP_CONTEXTMENU: */
         case HELP_FINDER:
             /* in fact, should be the topic dialog box */
+            WINE_FIXME("HELP_FINDER: stub\n");
             if (ptr)
             {
                 MACRO_JumpHash(ptr, "main", 0);
@@ -395,6 +397,7 @@ static BOOL     WINHELP_ReuseWindow(WINHELP_WINDOW* win, WINHELP_WINDOW* oldwin,
     win->hTextWnd      = oldwin->hTextWnd;
     win->hHistoryWnd   = oldwin->hHistoryWnd;
     oldwin->hMainWnd = oldwin->hButtonBoxWnd = oldwin->hTextWnd = oldwin->hHistoryWnd = 0;
+    win->hBrush = oldwin->hBrush;
 
     SetWindowLong(win->hMainWnd,      0, (LONG)win);
     SetWindowLong(win->hButtonBoxWnd, 0, (LONG)win);
@@ -481,6 +484,7 @@ BOOL WINHELP_CreateHelpWindow(HLPFILE_PAGE* page, HLPFILE_WINDOWINFO* wi,
     HWND hWnd;
     BOOL bPrimary;
     BOOL bPopup;
+    LPSTR name;
 
     bPrimary = !lstrcmpi(wi->name, "main");
     bPopup = wi->win_style & WS_POPUP;
@@ -493,8 +497,9 @@ BOOL WINHELP_CreateHelpWindow(HLPFILE_PAGE* page, HLPFILE_WINDOWINFO* wi,
     win->next = Globals.win_list;
     Globals.win_list = win;
 
-    win->lpszName = (char*)win + sizeof(WINHELP_WINDOW);
-    lstrcpy((char*)win->lpszName, wi->name);
+    name = (char*)win + sizeof(WINHELP_WINDOW);
+    lstrcpy(name, wi->name);
+    win->lpszName = name;
 
     win->page = page;
 
@@ -581,6 +586,20 @@ BOOL WINHELP_CreateHelpWindowByHash(HLPFILE* hlpfile, LONG lHash,
     return WINHELP_CreateHelpWindow(page, wi, nCmdShow);
 }
 
+/***********************************************************************
+ *
+ *           WINHELP_CreateHelpWindowByMap
+ */
+BOOL WINHELP_CreateHelpWindowByMap(HLPFILE* hlpfile, LONG lMap,
+                                   HLPFILE_WINDOWINFO* wi, int nCmdShow)
+{
+    HLPFILE_PAGE*       page = NULL;
+
+    page = HLPFILE_PageByMap(hlpfile, lMap);
+    if (page) page->file->wRefCount++;
+    return WINHELP_CreateHelpWindow(page, wi, nCmdShow);
+}
+
 /***********************************************************************
  *
  *           WINHELP_MainWndProc
@@ -755,7 +774,7 @@ static LRESULT CALLBACK WINHELP_ButtonBoxWndProc(HWND hWnd, UINT msg, WPARAM wPa
             SIZE textsize;
             if (!button->hWnd)
             {
-                button->hWnd = CreateWindow(STRING_BUTTON, (LPSTR) button->lpszName,
+                button->hWnd = CreateWindow(STRING_BUTTON, button->lpszName,
                                             WS_CHILD | WS_VISIBLE | BS_PUSHBUTTON,
                                             0, 0, 0, 0,
                                             hWnd, (HMENU) button->wParam,
@@ -857,6 +876,7 @@ static LRESULT CALLBACK WINHELP_TextWndProc(HWND hWnd, UINT msg, WPARAM wParam,
         win = (WINHELP_WINDOW*) ((LPCREATESTRUCT) lParam)->lpCreateParams;
         SetWindowLong(hWnd, 0, (LONG) win);
         win->hTextWnd = hWnd;
+        win->hBrush = CreateSolidBrush(win->info->sr_color);
         if (win->info->win_style & WS_POPUP) Globals.hPopupWnd = win->hMainWnd = hWnd;
         WINHELP_InitFonts(hWnd);
         break;
@@ -989,6 +1009,8 @@ static LRESULT CALLBACK WINHELP_TextWndProc(HWND hWnd, UINT msg, WPARAM wParam,
         win = (WINHELP_WINDOW*) GetWindowLong(hWnd, 0);
         scroll_pos = GetScrollPos(hWnd, SB_VERT);
 
+        /* No DPtoLP needed - MM_TEXT map mode */
+        if (ps.fErase) FillRect(hDc, &ps.rcPaint, win->hBrush);
         for (line = win->first_line; line; line = line->next)
         {
             for (part = &line->first_part; part; part = part->next)
@@ -998,6 +1020,7 @@ static LRESULT CALLBACK WINHELP_TextWndProc(HWND hWnd, UINT msg, WPARAM wParam,
                 case hlp_line_part_text:
                     SelectObject(hDc, part->u.text.hFont);
                     SetTextColor(hDc, part->u.text.color);
+                    SetBkColor(hDc, win->info->sr_color);
                     TextOut(hDc, part->rect.left, part->rect.top - scroll_pos,
                             part->u.text.lpsText, part->u.text.wTextLen);
                     if (part->u.text.wUnderline)
@@ -1043,11 +1066,35 @@ static LRESULT CALLBACK WINHELP_TextWndProc(HWND hWnd, UINT msg, WPARAM wParam,
                     break;
                 case hlp_line_part_metafile:
                     {
-                        POINT   pt;
+                        HDC hMemDC;
+                        HBITMAP hBitmap;
+                        SIZE sz;
+                        RECT rc;
 
-                        SetViewportOrgEx(hDc, part->rect.left, part->rect.top - scroll_pos, &pt);
-                        PlayMetaFile(hDc, part->u.metafile.hMetaFile);
-                        SetViewportOrgEx(hDc, pt.x, pt.y, NULL);
+                        sz.cx = part->rect.right - part->rect.left;
+                        sz.cy = part->rect.bottom - part->rect.top;
+                        hMemDC = CreateCompatibleDC(hDc);
+                        hBitmap = CreateCompatibleBitmap(hDc, sz.cx, sz.cy);
+                        SelectObject(hMemDC, hBitmap);
+                        SelectObject(hMemDC, win->hBrush);
+                        rc.left = 0;
+                        rc.top = 0;
+                        rc.right = sz.cx;
+                        rc.bottom = sz.cy;
+                        FillRect(hMemDC, &rc, win->hBrush);
+                        SetMapMode(hMemDC, part->u.metafile.mm);
+                        SetWindowExtEx(hMemDC, sz.cx, sz.cy, 0);
+                        SetViewportExtEx(hMemDC, sz.cx, sz.cy, 0);
+                        SetWindowOrgEx(hMemDC, 0, 0, 0);
+                        SetViewportOrgEx(hMemDC, 0, 0, 0);
+                        PlayMetaFile(hMemDC, part->u.metafile.hMetaFile);
+                        SetMapMode(hMemDC, MM_TEXT);
+                        SetWindowOrgEx(hMemDC, 0, 0, 0);
+                        SetViewportOrgEx(hMemDC, 0, 0, 0);
+                        BitBlt(hDc, part->rect.left, part->rect.top - scroll_pos,
+                               sz.cx, sz.cy, hMemDC, 0, 0, SRCCOPY);
+                        DeleteDC(hMemDC);
+                        DeleteObject(hBitmap);
                     }
                     break;
                 }
@@ -1079,8 +1126,8 @@ static LRESULT CALLBACK WINHELP_TextWndProc(HWND hWnd, UINT msg, WPARAM wParam,
             HLPFILE*            hlpfile;
             HLPFILE_WINDOWINFO* wi;
 
-            mouse.x = LOWORD(lParam);
-            mouse.y = HIWORD(lParam);
+            mouse.x = (short)LOWORD(lParam);
+            mouse.y = (short)HIWORD(lParam);
 
             if (part->link) switch (part->link->cookie)
             {
@@ -1122,6 +1169,7 @@ static LRESULT CALLBACK WINHELP_TextWndProc(HWND hWnd, UINT msg, WPARAM wParam,
         if (hWnd == Globals.hPopupWnd) Globals.hPopupWnd = 0;
 
         bExit = (Globals.wVersion >= 4 && !lstrcmpi(win->lpszName, "main"));
+        DeleteObject(win->hBrush);
 
         WINHELP_DeleteWindow(win);
 
@@ -1569,8 +1617,23 @@ static BOOL WINHELP_SplitLines(HWND hWnd, LPSIZE newsize)
                     gfxSize.cx = dibs.dsBm.bmWidth;
                     gfxSize.cy = dibs.dsBm.bmHeight;
                 }
-                else gfxSize = p->u.gfx.u.mf.mfSize;
-                    
+                else
+                {
+                    LPMETAFILEPICT lpmfp = &p->u.gfx.u.mfp;
+                    if (lpmfp->mm == MM_ANISOTROPIC || lpmfp->mm == MM_ISOTROPIC)
+                    {
+                        gfxSize.cx = MulDiv(lpmfp->xExt, GetDeviceCaps(hDc, HORZRES),
+                                            100*GetDeviceCaps(hDc, HORZSIZE));
+                        gfxSize.cy = MulDiv(lpmfp->yExt, GetDeviceCaps(hDc, VERTRES),
+                                            100*GetDeviceCaps(hDc, VERTSIZE));
+                    }
+                    else
+                    {
+                        gfxSize.cx = lpmfp->xExt;
+                        gfxSize.cy = lpmfp->yExt;
+                    }
+                }
+
                 free_width = rect.right - ((part && *line) ? (*line)->rect.right : rect.left) - space.cx;
                 if (free_width <= 0)
                 {
@@ -1592,7 +1655,8 @@ static BOOL WINHELP_SplitLines(HWND hWnd, LPSIZE newsize)
                 else
                 {
                     ref_part->cookie = hlp_line_part_metafile;
-                    ref_part->u.metafile.hMetaFile = p->u.gfx.u.mf.hMetaFile;
+                    ref_part->u.metafile.hMetaFile = p->u.gfx.u.mfp.hMF;
+                    ref_part->u.metafile.mm = p->u.gfx.u.mfp.mm;
                 }
             }
             break;
